@@ -83,6 +83,7 @@
 /* storage types */
 #define UDM_DBMODE_SINGLE	0
 #define UDM_DBMODE_MULTI	1
+#define UDM_DBMODE_FLY          2
 #define UDM_DBMODE_BLOB		6
 
 
@@ -158,6 +159,7 @@
 #define UDM_WORD_ORIGIN_SPELL   2
 #define UDM_WORD_ORIGIN_SYNONYM 4
 #define UDM_WORD_ORIGIN_STOP    8
+#define UDM_WORD_ORIGIN_SUGGEST 16
 
 /* Locking mutex numbers */
 #define UDM_LOCK_CONF		0
@@ -182,14 +184,17 @@ typedef struct stat_list_struct{
 } UDM_STATLIST;
 /************************ VARLISTs ************************/
 
+/* Various variable flags */
+#define UDM_VARFLAG_NOCLONE	1	/* Ignore for clone detection */ 
+#define UDM_VARFLAG_USERDEF	2	/* User defined section       */
+
 typedef struct udm_var_st {
 	int			section;	/**< Number 0..255   */
 	size_t			maxlen;		/**< Max length      */
 	size_t			curlen;		/**< Cur length      */
 	char			*val;		/**< Field Value     */
-        char                    *txt_val;       /**< Field Value in plain text */
 	char			*name;		/**< Field Name      */
-	struct udm_varlist_st	*subvar;	/**< for Nested vars */
+	int			flags;
 } UDM_VAR;
 
 typedef struct udm_varlist_st {
@@ -231,10 +236,6 @@ typedef struct {
 typedef struct {
 	size_t		min_word_len;
 	size_t		max_word_len;
-	size_t		correct_factor;
-	size_t		incorrect_factor;
-	size_t		number_factor;
-	size_t		alnum_factor;
 } UDM_WORDPARAM;
 
 
@@ -249,6 +250,8 @@ typedef struct {
         urlid_t         site_id;
         time_t          last_mod_time;
         double          pop_rank;
+	char            *url;
+        char            *section;
 } UDM_URLDATA;
 
 typedef struct {
@@ -383,6 +386,7 @@ typedef struct {
 	int	method;
         urlid_t site_id;
         urlid_t server_id;
+        urlid_t rec_id;
 } UDM_HREF;
 
 typedef struct {
@@ -446,7 +450,6 @@ typedef struct udm_url {
 	char	*anchor;
 	int	port;
 	int	default_port;
-        int     freeme;
 } UDM_URL;
 
 
@@ -495,73 +498,77 @@ typedef struct {
 	UDM_PARSER	*Parser;
 } UDM_PARSERLIST;
 
-/* Unicode regex lite BEGIN */
 
-#define UDM_UNIREG_SUB	1
-#define UDM_UNIREG_BEG	2
-#define UDM_UNIREG_END	3
-#define UDM_UNIREG_INC	4
-#define UDM_UNIREG_EXC	5
+/******* Ispell BEGIN ********/
 
-typedef struct{
-	int		type;
-	int		*str;
-} UDM_UNIREG_TOK;
+#define UDM_SPELL_NOPREFIX 1
 
-typedef struct {
-	size_t		ntokens;
-	UDM_UNIREG_TOK	*Token;
-} UDM_UNIREG_EXP;
-
-/* Unicode regex lite END */
-
-
-/* Ispell BEGIN */
-
-
-typedef struct spell_struct {
-	int		*word;
-	char		flag[11];
-	char		lang[33];
+typedef struct udm_spell_st
+{
+  char *word;
+  char *flags;
 } UDM_SPELL;
 
+#define UDM_SPELL_LANGLEN 32
+#define UDM_SPELL_CSETLEN 32
+#define UDM_SPELL_FILELEN 128
 
-typedef struct aff_struct {
-	char		flag;
-	char		type;
-	char		lang[33];
-	int		mask[41];
-        int		find[16];
-	int		repl[16];
-	UDM_UNIREG_EXP	reg;
-	size_t		replen;
-        size_t		findlen;
-        char		compile;
-} UDM_AFFIX;
-
-typedef struct Tree_struct {
-	int		Left[256];
-	int		Right[256];
-        char		lang[3];
-} Tree_struct;
-
-typedef struct {
-	size_t		naffixes;
-	size_t		maffixes;
-	UDM_AFFIX	*Affix;
-	Tree_struct	PrefixTree[UDM_LANGPERDOC];
-	Tree_struct	SuffixTree[UDM_LANGPERDOC];
-} UDM_AFFIXLIST;
-
-typedef struct {
-	size_t		nspell;
-	size_t		mspell;
-        size_t          nLang;
-	UDM_SPELL	*Spell;
-	Tree_struct	SpellTree[UDM_LANGPERDOC];
+typedef struct udm_dict_st
+{
+  char  lang[UDM_SPELL_LANGLEN];
+  char  cset[UDM_SPELL_CSETLEN];
+  char  fname[UDM_SPELL_FILELEN];
+  UDM_CHARSET *cs;
+  char   *fbody;
+  size_t nitems;
+  size_t mitems;
+  UDM_SPELL *Item;
 } UDM_SPELLLIST;
 
-/* Ispell END */
+
+typedef struct udm_spelllistlist_st
+{
+  size_t nitems;
+  size_t mitems;
+  size_t nspell;              /* Backward capability with php-4.3.x */
+  UDM_SPELLLIST *Item;
+} UDM_SPELLLISTLIST;
+
+
+typedef struct udm_aff_st
+{
+  char flag;
+  char type;
+  regex_t regex;
+  char *find;
+  char *repl;
+  char *mask;
+  size_t findlen;
+  size_t replen;
+} UDM_AFFIX;
+
+
+typedef struct udm_afflist_st
+{
+  size_t mitems;
+  size_t nitems;
+  char  lang[UDM_SPELL_LANGLEN];
+  char  cset[UDM_SPELL_CSETLEN];
+  char  fname[UDM_SPELL_FILELEN];
+  UDM_CHARSET *cs;
+  UDM_AFFIX *Item;
+} UDM_AFFIXLIST;
+
+
+typedef struct udm_afflistlist_st
+{
+  size_t mitems;
+  size_t nitems;
+  UDM_AFFIXLIST *Item;
+} UDM_AFFIXLISTLIST;
+
+
+/******* Ispell END **********/
 
 
 typedef struct{
@@ -595,7 +602,6 @@ typedef struct{
 typedef struct {
 	size_t		order;
 	size_t		count;
-	udmhash32_t	crcword;
 	char		*word;
 	int		*uword;
 	size_t		len;
@@ -604,6 +610,7 @@ typedef struct {
 } UDM_WIDEWORD;
 
 typedef struct {
+	int		wm;    /* Search mode: wrd, sub, beg, end */
 	size_t		nuniq;
 	size_t		nwords;
 	UDM_WIDEWORD	*Word;
@@ -657,6 +664,7 @@ typedef struct {
 #define UDM_STACK_NOT	 5
 #define UDM_STACK_PHRASE 6
 #define UDM_STACK_WORD	 200
+#define UDM_STACK_STOP   201
 
 typedef struct {
 	size_t		ncstack, mcstack;
@@ -721,6 +729,7 @@ typedef struct udm_config_struct {
 	UDM_MATCHLIST	MimeTypes;	/**< For AddType commands       */
 	UDM_MATCHLIST	Filters;	/**< Allow, Disallow,etc        */
 	UDM_MATCHLIST	SectionFilters; /**< IndexIf, NoIndexIf         */
+        UDM_MATCHLIST   SectionMatch;   /**< User defined sections      */
 	
 	UDM_RESULT	Targets;	/**< Targets cache              */
 	
@@ -734,8 +743,8 @@ typedef struct udm_config_struct {
 	UDM_PARSERLIST	Parsers;	/**< External  parsers          */
 	UDM_DBLIST	dbl;		/**< Searchd addresses	      */
 	UDM_HOSTLIST	Hosts;		/**< Resolve cache              */
-	UDM_SPELLLIST	Spells;		/**< For ispell dictionaries    */
-	UDM_AFFIXLIST	Affixes;	/**< For ispell affixes         */
+	UDM_SPELLLISTLIST Spells;	/**< For ispell dictionaries    */
+	UDM_AFFIXLISTLIST Affixes;	/**< For ispell affixes         */
 	UDM_WORDPARAM	WordParam;	/**< Word limits                */
         UDM_CHINALIST   Chi;            /**< Chinese words list         */
         UDM_CHINALIST   Thai;           /**< Thai words list            */
@@ -743,8 +752,6 @@ typedef struct udm_config_struct {
 	/* Various file descriptors */
 	int		is_log_open;	/**< if UdmOpenLog is already called   */
 	FILE		*logFD;		/**< FILE structure, syslog descriptor */
-        int             logs_only;      /**< Cache mode writes mode            */
-        int             do_store;       /**< Compressed copies storage flag    */
 	int		CVS_ignore;	/**< Skip CVS directgories - for tests */
 	void (*ThreadInfo)(struct udm_indexer_struct *,const char * state,const char * str);
 	void (*LockProc)(struct udm_indexer_struct *,int command,int type,const char *fname,int lineno);
@@ -871,6 +878,7 @@ typedef struct {
 	int	follow;
 	int	index;
 	int	comment;
+	int	nonbreaking;
 	char	*lasthref;
         void    (*next_b)(void *t);
         void    (*next_e)(void *t);
@@ -913,6 +921,8 @@ typedef struct udm_cfg_st {
 
 enum udm_indcmd
 {
+  UDM_IND_AMBIGUOUS,
+  UDM_IND_UNKNOWN,
   UDM_IND_INDEX,
   UDM_IND_STAT,
   UDM_IND_CREATE,
@@ -922,7 +932,9 @@ enum udm_indcmd
   UDM_IND_SQLMON,
   UDM_IND_CHECKCONF,
   UDM_IND_CONVERT,
-  UDM_IND_MULTI2BLOB
+  UDM_IND_MULTI2BLOB,
+  UDM_IND_EXPORT,
+  UDM_IND_WRDSTAT
 };
 
 #endif
