@@ -58,9 +58,11 @@
 #define UDM_URL_ACTION_LINKS_DELETE     21
 #define UDM_URL_ACTION_ADD_LINK		22
 #define UDM_URL_ACTION_GET_CACHED_COPY	23
+#define UDM_URL_ACTION_WRDSTAT		24
 
 #define UDM_RES_ACTION_DOCINFO		1
 #define UDM_RES_ACTION_INSWORDS		2
+#define UDM_RES_ACTION_SUGGEST		3
 
 #define UDM_CAT_ACTION_PATH		1
 #define UDM_CAT_ACTION_LIST		2
@@ -91,7 +93,7 @@
 #define UDM_LIMFNAME_CTYPE "lim_ctype"
 #define UDM_LIMFNAME_SITE  "lim_site"
 
-extern void	*UdmDBInit(void *db);
+
 extern void	UdmDBFree(void *db);
 
 extern __C_LINK int __UDMCALL UdmURLAction(UDM_AGENT *A, UDM_DOCUMENT   *D, int cmd);
@@ -110,10 +112,8 @@ extern __C_LINK int __UDMCALL UdmStatAction(UDM_AGENT *A, UDM_STATLIST *S);
 extern __C_LINK int __UDMCALL UdmTrack(UDM_AGENT * query, UDM_RESULT *Res);
 extern __C_LINK UDM_RESULT * __UDMCALL UdmCloneList(UDM_AGENT * Indexer, UDM_DOCUMENT *Doc);
 
-extern UDM_DBLIST	*UdmDBListInit(UDM_DBLIST *List);
-extern size_t		UdmDBListAdd(UDM_DBLIST *List, const char * addr, int mode);
 extern void		UdmDBListFree(UDM_DBLIST *List);
-extern int UdmDBSetAddr(UDM_DB *db, const char *dbaddr, int mode);
+
 extern unsigned int     UdmGetCategoryId(UDM_ENV *Conf, char *category);
 
 extern int UdmFindWords(UDM_AGENT *A, UDM_RESULT *Res);
@@ -121,6 +121,18 @@ extern int UdmHTDBGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc);
 
 extern int UdmCheckUrlid(UDM_AGENT *A, urlid_t id);
 
+extern int UdmDBSetAddr(UDM_DB *db, const char *dbaddr, int mode);
+/******************/
+/* changed by prv for Win32(COM) */
+extern __C_LINK UDM_DBLIST	* __UDMCALL UdmDBListInit(UDM_DBLIST *List);
+extern __C_LINK size_t	__UDMCALL UdmDBListAdd(UDM_DBLIST *List, const char * addr, int mode);
+
+extern __C_LINK void * __UDMCALL UdmDBInit(void *db);
+extern __C_LINK int __UDMCALL UdmGetDocCount(UDM_AGENT * Indexer,UDM_DB *db);
+
+/******************/
+
+
 /******************/
 
 #ifdef HAVE_SQL
@@ -140,22 +152,39 @@ extern int UdmTrackSQL(UDM_AGENT * query, UDM_RESULT *Res, UDM_DB *db);
 extern int UdmCloneListSQL(UDM_AGENT * Indexer, UDM_DOCUMENT *Doc, UDM_RESULT *Res, UDM_DB *db);
 extern int UdmLoadURLDataSQL(UDM_AGENT *A, UDM_RESULT *R, UDM_DB *db);
 extern int UdmTargetsSQL(UDM_AGENT *Indexer, UDM_DB *db);
+extern int UdmUserCacheStoreSQL(UDM_AGENT *Indexer, UDM_RESULT *Res, UDM_DB *db);
 #endif
 
 /* MultiCache stuff. */
 extern UDM_MULTI_CACHE *UdmMultiCacheInit (UDM_MULTI_CACHE *cache);
 extern void UdmMultiCacheFree (UDM_MULTI_CACHE *cache);
-extern int UdmMultiCacheWrite (UDM_AGENT *Indexer, UDM_DB *db, size_t limit);
-extern int UdmMultiCacheFlush (UDM_AGENT *Indexer);
 extern size_t UdmMultiCacheAdd (UDM_MULTI_CACHE *cache, urlid_t url_id, unsigned char reindex, UDM_WORD *word);
 
 extern int UdmMulti2BlobSQL (UDM_AGENT *Indexer, UDM_DB *db);
+extern int UdmSingle2BlobSQL (UDM_AGENT *Indexer, UDM_DB *db);
 extern int UdmMulti2Blob (UDM_AGENT *Indexer);
 extern UDM_BLOB_CACHE *UdmBlobCacheInit (UDM_BLOB_CACHE *cache);
 extern void UdmBlobCacheFree (UDM_BLOB_CACHE *cache);
-extern size_t UdmBlobCacheAdd (UDM_BLOB_CACHE *cache, urlid_t url_id, unsigned char secno, const char *word, size_t nintags, const char *intag);
+extern size_t UdmBlobCacheAdd (UDM_BLOB_CACHE *cache, urlid_t url_id,
+                               unsigned char secno, const char *word,
+                               size_t nintags, const char *intag,
+                               size_t intag_length);
 extern void UdmBlobCacheSort (UDM_BLOB_CACHE *cache);
 
+extern UDM_WORD_CACHE *UdmWordCacheInit (UDM_WORD_CACHE *cache);
+extern void UdmWordCacheFree (UDM_WORD_CACHE *cache);
+extern void UdmWordCacheSort (UDM_WORD_CACHE *cache);
+extern int UdmWordCacheAdd (UDM_WORD_CACHE *cache, urlid_t url_id, const char *word, int intag);
+extern int UdmWordCacheAddURL (UDM_WORD_CACHE *cache, urlid_t url_id);
+extern int UdmWordCacheWrite (UDM_AGENT *Indexer, UDM_DB *db, size_t limit);
+extern int UdmWordCacheFlush (UDM_AGENT *Indexer);
+
+/* DBModeFly */
+extern int UdmDBModeFlyWrite (UDM_AGENT *Indexer, UDM_DB *db, size_t limit);
+extern int UdmDBModeFlyMerge (UDM_AGENT *Indexer, UDM_DB *db);
+
+extern int UdmExport (UDM_AGENT *Indexer);
+extern int UdmExportSQL (UDM_AGENT *Indexer, UDM_DB *db);
 
 extern void UdmDecodeHex8Str(const char *hex_str, uint4 *hi, uint4 *lo, uint4 *fhi, uint4 *flo);
 extern __C_LINK int __UDMCALL UdmAddSearchLimit(UDM_AGENT *Agent, int type, const char *file_name, const char *val);
