@@ -20,16 +20,6 @@
 
 #include <limits.h>
 
-#if (HAVE_MYSQL)
-
-#include <mysql.h>
-#define ER_DUP_ENTRY            1062
-#define ER_DUP_KEY		1022
-#define CR_SERVER_LOST          2013
-#define CR_SERVER_GONE_ERROR    2006
-#define ER_SERVER_SHUTDOWN      1053
-#endif
-
 #if (HAVE_PGSQL)
 #include <libpq-fe.h>
 #endif
@@ -69,10 +59,6 @@
 #include <sqlcli1.h>
 #endif
 
-#if HAVE_IBASE
-#include <ibase.h>
-#endif
-
 #if HAVE_CTLIB
 #include <ctpublic.h>
 #endif
@@ -81,23 +67,9 @@
 #include <sqlite.h>
 #endif
 
-#if HAVE_ORACLE8
-#include <oci.h>
-#endif
-
-
-#ifdef HAVE_ORACLE8
-
-#define	MAX_COLS_IN_TABLE	32
-#define MAX_BIND_PARAM		4
-#define BUF_OUT_SIZE		128
-struct param_struct{
-	int out_rec;
-	int out_pos[MAX_BIND_PARAM];
-	int out_pos_val[MAX_BIND_PARAM][BUF_OUT_SIZE];
-};
-#endif
-
+#define UDM_SQLTYPE_UNKNOWN 0
+#define UDM_SQLTYPE_LONGVARBINARY 1
+#define UDM_SQLTYPE_LONGVARCHAR 2
 
 /* Multi-dict mode defines */
 #define MULTI_DICTS	0xff
@@ -126,7 +98,7 @@ typedef struct {
 typedef struct {
 	size_t nRows;
 	size_t nCols;
-	int DBDriver;
+	size_t curRow;
 	
 	UDM_SQLFIELD	*Fields;
 	UDM_PSTR	*Items;
@@ -134,14 +106,8 @@ typedef struct {
 #ifdef HAVE_PGSQL
 	PGresult  *pgsqlres;
 #endif
-	
-#ifdef HAVE_ORACLE8
-	char	*defbuff[MAX_COLS_IN_TABLE]; /* Buffers for OCIStmtFetch */
-	int	col_size[MAX_COLS_IN_TABLE]; /* Size of column */
-	int	col_type[MAX_COLS_IN_TABLE]; /* Type of column */
-	sb2	indbuff[MAX_COLS_IN_TABLE][BUF_OUT_SIZE];  /* Indicators for NULLs */
-#endif
-
+	void *specific;
+	struct udm_db_st *db;
 } UDM_SQLRES;
 
 typedef struct {
@@ -178,10 +144,11 @@ typedef struct {
 
 typedef struct {
 	unsigned char secno;
-	const char *word;
+	char *word;
 	urlid_t url_id;
-	size_t nintags;
-	const char *intags;
+	size_t nintags;    /* Length in coords */
+	size_t ntaglen;    /* Length in bytes  */
+	char *intags;
 } UDM_BLOB_CACHE_WORD;
 
 typedef struct {
@@ -191,7 +158,54 @@ typedef struct {
 	UDM_BLOB_CACHE_WORD *words;
 } UDM_BLOB_CACHE;
 
-typedef struct struct_udm_db {
+typedef struct {
+	urlid_t url_id;
+	unsigned char secno;
+	unsigned char seed;
+	unsigned short coord;
+	char *word;
+} UDM_WORD_CACHE_WORD;
+
+typedef struct {
+	int free;
+	size_t nbytes;
+	size_t nwords;
+	size_t awords;
+	UDM_WORD_CACHE_WORD *words;
+	size_t nurls;
+	size_t aurls;
+	urlid_t *urls;
+} UDM_WORD_CACHE;
+
+struct udm_db_st;
+
+
+typedef struct udm_db_handler_st
+{
+  char	*(*SQLEscStr)(struct udm_db_st *db, char *to, const char *from, size_t len);
+  int    (*SQLQuery)(struct udm_db_st *db, UDM_SQLRES *R, const char *query);
+  void   (*SQLClose)(struct udm_db_st *db);
+  int    (*SQLBegin)(struct udm_db_st *db);
+  int    (*SQLCommit)(struct udm_db_st *db);
+  int    (*SQLPrepare)(struct udm_db_st *db, const char *query);
+  int    (*SQLBind)(struct udm_db_st *db, int position, void *data, size_t size, int type);
+  int    (*SQLExec)(struct udm_db_st *db);
+  int    (*SQLFetchRow)(struct udm_db_st *db, UDM_SQLRES *R, UDM_PSTR *);
+  int    (*SQLStoreResult)(struct udm_db_st *db, UDM_SQLRES *R);
+  int    (*SQLFreeResult)(struct udm_db_st *db, UDM_SQLRES *R);
+  int    (*SQLExecDirect)(struct udm_db_st *db, UDM_SQLRES *R, const char *q);
+} UDM_SQLDB_HANDLER;
+
+extern UDM_SQLDB_HANDLER udm_sqldb_ctlib_handler;
+extern UDM_SQLDB_HANDLER udm_sqldb_mysql_handler;
+extern UDM_SQLDB_HANDLER udm_sqldb_pgsql_handler;
+extern UDM_SQLDB_HANDLER udm_sqldb_ibase_handler;
+extern UDM_SQLDB_HANDLER udm_sqldb_sqlite_handler;
+extern UDM_SQLDB_HANDLER udm_sqldb_odbc_handler;
+extern UDM_SQLDB_HANDLER udm_sqldb_oracle_handler;
+
+typedef struct udm_db_st
+{
 	int	freeme;
 	char	*DBName;
 	int	DBMode;
@@ -201,11 +215,7 @@ typedef struct struct_udm_db {
 	int	DBDriver;
 	
 	int	DBSQL_IN;
-	int	DBSQL_LIMIT;
-	int	DBSQL_GROUP;
-	int	DBSQL_TRUNCATE;
-	int	DBSQL_SELECT_FROM_DELETE;
-        int     DBSQL_SUBSELECT;
+        int     flags;
 	
 	int	connected;
 	int	res_limit;
@@ -214,16 +224,10 @@ typedef struct struct_udm_db {
 	int	errcode;
 	char	errstr[2048];
 	
-	int		searchd;	/* Searchd daemon descriptor         */
-        UDM_VARLIST     Vars;           /* optional parameters and variables*/
-
-#ifdef HAVE_MYSQL
-	MYSQL  mysql;
-#endif
-
-#ifdef HAVE_PGSQL
-	PGconn	*pgsql;
-#endif
+	int		  searchd;    /* Searchd daemon descriptor         */
+        UDM_VARLIST       Vars;       /* optional parameters and variables */
+	UDM_SQLDB_HANDLER *sql;
+	void	*specific;
 
 #if (HAVE_IODBC || HAVE_UNIXODBC || HAVE_SOLID || HAVE_VIRT || HAVE_EASYSOFT || HAVE_SAPDB)
 	HDBC	hDbc;
@@ -236,34 +240,7 @@ typedef struct struct_udm_db {
 	SQLHANDLE	hEnv;
 	SQLHANDLE	hstmt;
 #endif
-
-#ifdef HAVE_IBASE
-	isc_db_handle	DBH;		/* database handle    */
-	ISC_STATUS	status[20];	/* status vector      */
-	isc_tr_handle   tr_handle;	/* transaction handle */ 
-#endif
-
-#ifdef HAVE_CTLIB
-	CS_CONTEXT	*ctx;
-	CS_CONNECTION	*conn;
-#endif
-
-#ifdef HAVE_SQLITE
-	struct sqlite	*sqlt;
-#endif
-
-#ifdef HAVE_ORACLE8
-	OCIEnv     *envhp;
-	OCIError   *errhp;
-	OCISvcCtx  *svchp;
-	OCIStmt	   *stmthp;
-	OCIParam   *param;
-	OCIDefine  *defb[MAX_COLS_IN_TABLE];
-	OCIBind    *bndhp[MAX_BIND_PARAM];
-	struct param_struct *par;
-#endif
-
-	UDM_MULTI_CACHE MultiCache;
+	UDM_WORD_CACHE WordCache;
 } UDM_DB;
 
 #endif
