@@ -19,9 +19,9 @@
 #define _UDM_ROBOTS_H
 
 extern UDM_ROBOT* UdmRobotFind(UDM_ROBOTS *Robots,const char *hostinfo);
-extern UDM_ROBOT* UdmRobotAddEmpty(UDM_ROBOTS *Robots,char *hostinfo);
+extern UDM_ROBOT* UdmRobotAddEmpty(UDM_ROBOTS *Robots,const char *hostinfo);
 extern UDM_ROBOT_RULE* UdmRobotRuleFind(UDM_ROBOTS *Robots,UDM_URL * URL);
 extern int UdmRobotListFree(UDM_ROBOTS *Robots);
-extern int UdmRobotParse(UDM_AGENT *Indexer, UDM_SERVER *Srv, char *content, char *hostinfo);
+extern int UdmRobotParse(UDM_AGENT *Indexer, UDM_SERVER *Srv, char *content, const char *hostinfo);
 
 #endif
