@@ -30,7 +30,7 @@ extern void UdmGroupByURL(UDM_AGENT *Agent,UDM_RESULT *Res);
 extern void UdmGroupBySite(UDM_AGENT *Agent, UDM_RESULT *Res);
 
 extern int  UdmPrepare(UDM_AGENT *query,UDM_RESULT *res);
-extern int  UdmParseQueryString(UDM_AGENT * Agent,UDM_VARLIST * vars,char * query_string);
+extern __C_LINK int __UDMCALL UdmParseQueryString(UDM_AGENT * Agent,UDM_VARLIST * vars,char * query_string);
 
 extern char *UdmHlConvert(UDM_WIDEWORDLIST *L,const char * src, UDM_CHARSET * lcs, UDM_CHARSET * bcs);
 extern int  UdmConvert(UDM_ENV *Conf, UDM_RESULT *Res,UDM_CHARSET *lcs,UDM_CHARSET *bcs);
