@@ -19,7 +19,8 @@
 #define _UDM_SGML_H
 
 extern __C_LINK char * __UDMCALL UdmSGMLUnescape(char * str);
+extern size_t UdmHTMLEncode(char *d, size_t dlen, const char *s, size_t slen);
 extern void UdmSGMLUniUnescape(int * ustr);
-extern int UdmSgmlToUni(char *sgml);
+extern int UdmSgmlToUni(const char *sgml);
 
 #endif
