@@ -28,6 +28,8 @@
 extern int  UdmUniToLower(int uni);
 extern __C_LINK void __UDMCALL UdmUniStrToLower(int * unistr);
 extern int  UdmUniCType(int u);
+extern void UdmStrToLower(UDM_CHARSET *cs, char *str, size_t bytelen);
+extern void UdmStrToLower8bit(UDM_CHARSET *cs, char *str, size_t bytelen);
 
 extern int  *UdmUniGetToken(int * s, int ** last);
 extern __C_LINK int  * __UDMCALL UdmUniGetSepToken(int * s, int ** last, int * ctype0);
