@@ -184,5 +184,8 @@ extern void UdmDSTRFree (UDM_DSTR *dstr);
 extern size_t UdmDSTRAppend (UDM_DSTR *dstr, const char *data, size_t size_data);
 extern size_t UdmDSTRAppendSTR (UDM_DSTR *dstr, const char *data);
 extern int UdmDSTRAppendf (UDM_DSTR *dstr, const char *fmt, ...);
+extern void UdmDSTRReset (UDM_DSTR *dstr);
+extern int UdmDSTRRealloc (UDM_DSTR *dstr, size_t size_data);
+extern void UdmSoundex(UDM_CHARSET *cs, char *dst, const char *src, size_t srclen);
 
 #endif /* _UDM_UTILS_H */
