@@ -18,13 +18,13 @@
 #ifndef _UDM_VARS_H
 #define _UDM_VARS_H
 
-extern UDM_VARLIST *UdmVarListInit(UDM_VARLIST * vars);
-extern void UdmVarListFree(UDM_VARLIST * vars);
+extern __C_LINK UDM_VARLIST * __UDMCALL UdmVarListInit(UDM_VARLIST * vars);
+extern __C_LINK void __UDMCALL UdmVarListFree(UDM_VARLIST * vars);
 extern void UdmVarFree(UDM_VAR *);
 
 extern int UdmVarListAddEnviron(UDM_VARLIST *vars, const char *name);
 
-extern int UdmVarListAddStr(UDM_VARLIST * vars,const char * name, const char * val);
+extern __C_LINK int __UDMCALL UdmVarListAddStr(UDM_VARLIST * vars,const char * name, const char * val);
 extern int UdmVarListAddInt(UDM_VARLIST * vars,const char * name, int val);
 extern int UdmVarListAddUnsigned(UDM_VARLIST * vars, const char * name, uint4 val);
 extern int UdmVarListAddDouble(UDM_VARLIST * vars, const char * name, double val);
@@ -48,10 +48,9 @@ extern UDM_VAR *UdmVarListFind(UDM_VARLIST * vars,const char * name);
 extern UDM_VAR *UdmVarListFindWithValue(UDM_VARLIST * vars,const char * name,const char * val);
 
 extern __C_LINK const char * __UDMCALL UdmVarListFindStr(UDM_VARLIST * vars,const char * name,const char * defval);
-extern const char * UdmVarListFindStrTxt(UDM_VARLIST * vars,const char * name,const char * defval);
-extern int          UdmVarListFindInt(UDM_VARLIST * vars,const char * name,int defval);
-extern unsigned     UdmVarListFindUnsigned(UDM_VARLIST * vars, const char * name, unsigned defval);
-extern double       UdmVarListFindDouble(UDM_VARLIST * vars, const char * name, double defval);
+extern __C_LINK int          UdmVarListFindInt(UDM_VARLIST * vars,const char * name,int defval);
+extern __C_LINK unsigned     UdmVarListFindUnsigned(UDM_VARLIST * vars, const char * name, unsigned defval);
+extern __C_LINK double       UdmVarListFindDouble(UDM_VARLIST * vars, const char * name, double defval);
 
 
 #endif
