@@ -18,7 +18,7 @@
 #ifndef _UDM_WILD_H
 #define _UDM_WILD_H
 
-extern int UdmWildCmp(const char *str, const char *exp);
-extern __C_LINK int __UDMCALL UdmWildCaseCmp(const char *str, const char *exp);
+extern int UdmWildCmp(const char *str, const char *wexp);
+extern __C_LINK int __UDMCALL UdmWildCaseCmp(const char *str, const char *wexp);
 
 #endif
