@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # $Source: /usr/home/bar/cvsroot/mnogosearch32/install.pl,v $
-# $Id: install.pl,v 1.4 2003/06/19 20:51:34 maxime Exp $
+# $Id: install.pl,v 1.6 2004/12/23 12:21:08 svoj Exp $
 
 use Cwd 'abs_path';
 
@@ -99,7 +99,7 @@ sub configure {
 
         if ($dmalloc eq 'yes') {
         	push @arg,"--enable-dmalloc";
-        } elsif ($pthreads eq 'no') {
+        } elsif ($dmalloc eq 'no') {
         	push @arg,"--disable-dmalloc";
 	}
 
@@ -178,23 +178,23 @@ sub configure {
 sub set_db {
 	print "Database settings\n";
 	print "-----------------\n";
-	while () {
-		print "Include built-in database support? (Use for small sites) (yes/no) [$builtin]: ";
-		$temp=read_in();
-		if (($temp eq '') || ($temp eq $builtin)) {
-			last;			
-		} elsif (($temp eq 'yes') || ($temp eq 'no')) {
-			$builtin=$temp;
-			last;
-		}
-	}	
-	
-	if ($builtin eq 'yes') {
-		$db_string='--with-built-in';
-		return;
-	} else {
-		$db_string='';
-	}
+#	while () {
+#		print "Include built-in database support? (Use for small sites) (yes/no) [$builtin]: ";
+#		$temp=read_in();
+#		if (($temp eq '') || ($temp eq $builtin)) {
+#			last;			
+#		} elsif (($temp eq 'yes') || ($temp eq 'no')) {
+#			$builtin=$temp;
+#			last;
+#		}
+#	}	
+#	
+#	if ($builtin eq 'yes') {
+#		$db_string='--with-built-in';
+#		return;
+#	} else {
+#		$db_string='';
+#	}
 	
 	while () {
 		print "Try to autodetect databases at known locations? (yes/no) [$auto]: ";
@@ -687,7 +687,7 @@ sub set_other {
 	}
 	
 	while () {
-		print "Enable DMALLOC support ? (yes/no) [$pthreads]: ";
+		print "Enable DMALLOC support ? (yes/no) [$dmalloc]: ";
 		$temp=read_in();
 		if (($temp eq '') || ($temp eq $dmalloc)) {
 			last;			
