@@ -11,14 +11,42 @@
 #include <sys/types.h>
 #include <time.h>
 #include <unistd.h>
+#include "../include/udm_config.h"
 
 #define UDM_TEST_PASS 0
 #define UDM_TEST_FAIL 1
 #define UDM_TEST_SKIP 2
 
-#define debug(STRING...) _debug(__FILE__, __LINE__, __FUNCTION__, ## STRING)
+#define UDM_FREE(x)		{if((x)!=NULL){free(x);x=NULL;}}
 
-FILE *log;
+FILE *logfile;
+
+
+static int UdmSetEnv(const char * name,const char * value){
+#ifdef HAVE_SETENV
+	return(setenv(name,value,1));
+#else
+#ifdef HAVE_PUTENV
+	int res;
+	char * s;
+	s=(char*)UdmMalloc(strlen(name)+strlen(value)+3);
+	sprintf(s,"%s=%s",name,value);
+	res=putenv(s);
+	UDM_FREE(s);
+	return res;
+#else
+	return 0;
+#endif
+#endif
+}
+
+static void UdmUnsetEnv(const char * name){
+#ifdef HAVE_UNSETENV
+	unsetenv(name);
+#else
+	UdmSetEnv(name,"");
+#endif
+}
 
 static char *str_store (char *dest, char *src) {
 	size_t d_size = (dest ? strlen(dest) : 0);
@@ -92,7 +120,7 @@ static char *mem_printf (const char *fmt, ...) {
         return(_);
 }
 
-static void _debug (const char *file, int line, const char *func, const char *fmt, ...) {
+static void debug (const char *fmt, ...) {
 	va_list list;
 	time_t t = time(NULL);
 	char *tim = ctime(&t);
@@ -105,9 +133,9 @@ static void _debug (const char *file, int line, const char *func, const char *fm
 	str = strf(fmt, list);
 	va_end(list);
 
-	fseek(log, 0, SEEK_END);
-	fprintf(log, "%s %s(%d) [%s]: %s\n", tim, file, line, func, str);
-	fflush(log);
+	fseek(logfile, 0, SEEK_END);
+	fprintf(logfile, "%s: %s\n", tim, str);
+	fflush(logfile);
 }
 
 static int testenv (char *key, char *val) {
@@ -117,6 +145,13 @@ static int testenv (char *key, char *val) {
 	return(0);
 }
 
+static int substrenv (char *key, char *val) {
+	char *p = getenv(key);
+	if (! p) return(1);
+	else if (! strstr(p, val)) return(2);
+	return(0);
+}
+
 static int mdiff (char *src, char *dst) {
 	int src_fd;
 	int dst_fd;
@@ -164,6 +199,59 @@ static int mdiff (char *src, char *dst) {
 	return(_);
 }
 
+typedef int (*qsort_cmp)(const void*, const void*);
+
+static int cmpdirent (char **a1, char **a2) {
+  return(strcmp(*a1, *a2));
+}
+
+static void freedir (char **dir) {
+	char **p;
+
+	if (! dir) return;
+	for (p = dir; *p; p++) UdmFree(*p);
+	UdmFree(dir);
+}
+
+static char **loaddir (const char *path, int sort) {
+  struct dirent *buf;
+  char **_, **tmp;
+  size_t nrecs = 0, arecs = 32;
+  DIR *dir;
+
+  if (! path) return(NULL);
+
+  dir = opendir(path);
+  if (! dir) return(NULL);
+  _ = UdmMalloc(arecs * sizeof(char *));
+  if (! _) {
+    closedir(dir);
+    return(NULL);
+  }
+
+  while ((buf = readdir(dir))) {
+    if (arecs < nrecs + 1) {
+      arecs += 32;
+      tmp = UdmRealloc(_, arecs * sizeof(char *));
+      if (! tmp) {
+        closedir(dir);
+	_[nrecs] = NULL;
+	freedir(_);
+	return(NULL);
+      }
+      _ = tmp;
+    }
+
+    _[nrecs++] = UdmStrdup(buf->d_name);
+  }
+
+  closedir(dir);
+
+  if (sort) UdmSort(_, nrecs, sizeof(char *), (qsort_cmp)cmpdirent);
+  _[nrecs] = NULL;
+  return(_);
+}
+
 static int UdmTest (char *test) {
 	char *p;
 	char *p1;
@@ -265,6 +353,17 @@ static int UdmTest (char *test) {
 			while (isspace(*p)) p++;
 			f2 = p;
 			cr = testenv(f1, f2);
+                } else if (! strncmp(p, "substrenv", 9)) {
+                        char *f1, *f2;
+			p += 10;
+			while (isspace(*p)) p++;
+			f1 = p;
+			while (*p && ! isspace(*p)) p++;
+			*p = 0;
+			p++;
+			while (isspace(*p)) p++;
+			f2 = p;
+			cr = substrenv(f1, f2);
 		} else {
 			free(str);
 			debug("Syntax error.\n");
@@ -314,7 +413,7 @@ static void UdmSetDBAddrs (char *str) {
 	a = split(",", str);
 	for (p = a; *p; p++) {
 		key = mem_printf("UDM_TEST_DBADDR%d", c);
-		setenv(key, *p, 1);
+		UdmSetEnv(key, *p);
 		c++;
 		free(key);
 	}
@@ -330,7 +429,7 @@ static void UdmUnSetDBAddrs (char *str) {
 	a = split(",", str);
 	for (p = a; *p; p++) {
 		key = mem_printf("UDM_TEST_DBADDR%d", c);
-		unsetenv(key);
+		UdmUnsetEnv(key);
 		c++;
 		free(key);
 	}
@@ -354,8 +453,6 @@ please use temporary databases for tests purposes.\n\
 }
 
 int main (int argc, char **argv) {
-	DIR *d;
-	struct dirent *de;
 	struct stat st;
 	int i;
 	char *p;
@@ -369,6 +466,8 @@ int main (int argc, char **argv) {
 	size_t test_fail = 0;
 	size_t test_skip = 0;
 	int res;
+	size_t rpos;
+	char **recs;
 	
 	mask= (argc == 2) ? argv[1] : NULL;
 	
@@ -388,12 +487,12 @@ int main (int argc, char **argv) {
 		return(1);
 	}
 
-	if (! (d = opendir(UDM_TEST_ROOT))) {
-		fprintf(stderr, "opendir '%s' failed (%s).", UDM_TEST_ROOT, strerror(errno));
+	if (! (recs = loaddir(UDM_TEST_ROOT, 1))) {
+		fprintf(stderr, "loaddir '%s' failed (%s).", UDM_TEST_ROOT, strerror(errno));
 		return(1);
 	}
 
-	if (! (log = fopen(UDM_TEST_LOG, "w"))) {
+	if (! (logfile = fopen(UDM_TEST_LOG, "w"))) {
 		fprintf(stderr, "fopen '%s' failed: %s.\n", UDM_TEST_LOG, strerror(errno));
 		return(1);
 	}
@@ -403,39 +502,40 @@ int main (int argc, char **argv) {
 
 	DBAddrs = split(";", UDM_TEST_DBADDR);
 	for (pdb = DBAddrs; *pdb; pdb++) {
+
 		UdmSetDBAddrs(*pdb);
 		printf("DBAddr: %s\n", *pdb);
 		debug("DBAddr: %s", *pdb);
-		rewinddir(d);
-		while ((de = readdir(d))) {
-			if (*de->d_name == '.') continue;
-			if (strncmp(de->d_name,"test",4)) continue;
-			if (mask && strcmp(de->d_name,mask)) continue;
-			p = mem_printf("%s/%s", UDM_TEST_ROOT, de->d_name);
+
+		for (rpos = 0; recs[rpos]; rpos++) {
+			if (*recs[rpos] == '.') continue;
+			if (strncmp(recs[rpos],"test",4)) continue;
+			if (mask && strcmp(recs[rpos],mask)) continue;
+			p = mem_printf("%s/%s", UDM_TEST_ROOT, recs[rpos]);
 			if (! p) {
 				debug("mem_printf failed.");
         			continue;
 			}
 			if (lstat(p, &st) < 0) {
-				debug("stat %s failed (%s).", de->d_name, strerror(errno));
+				debug("stat %s failed (%s).", recs[rpos], strerror(errno));
 				continue;
 			}
 			if (! S_ISDIR(st.st_mode)) continue;
-			debug("Starting test %s",de->d_name);
-			printf("%s", de->d_name);
-			for (i = 0; i < (int)(35 - strlen(de->d_name)); i++) putchar('.');
-			if (setenv("UDM_ETC_DIR", p, 1) < 0) {
+			debug("Starting test %s",recs[rpos]);
+			printf("%s", recs[rpos]);
+			for (i = 0; i < (int)(35 - strlen(recs[rpos])); i++) putchar('.');
+			if (UdmSetEnv("UDM_ETC_DIR", p) < 0) {
 				debug("setenv failed (%s).", strerror(errno));
 				free(p);
 				continue;
 			}
-			if (setenv("UDM_TEST_DIR", p, 1) < 0) {
+			if (UdmSetEnv("UDM_TEST_DIR", p) < 0) {
 				debug("setenv failed (%s).", strerror(errno));
 				free(p);
 				continue;
 			}
 			free(p);
-			p = mem_printf("%s/%s/test.cmd", UDM_TEST_ROOT, de->d_name);
+			p = mem_printf("%s/%s/test.cmd", UDM_TEST_ROOT, recs[rpos]);
 			if (! p) {
 				debug("mem_printf failed.");
 				continue;
@@ -449,7 +549,7 @@ int main (int argc, char **argv) {
 				case UDM_TEST_SKIP: printf("skipped.\n"); test_skip++; break;
 			}
 			debug("----------------------------------");
-			debug("------------- END OF %s",de->d_name);
+			debug("------------- END OF %s",recs[rpos]);
 			debug("----------------------------------");
 		}
 		UdmUnSetDBAddrs(*pdb);
