@@ -73,7 +73,7 @@ static void PUSHARG(UDM_BOOLSTACK * s,unsigned long arg){
 	s->nastack++;
 	if (s->nastack >= s->mastack) {
 	  s->mastack += UDM_MAXSTACK;
-	  s->astack = (unsigned long*)realloc(s->astack, s->mastack * sizeof(unsigned long));
+	  s->astack = (unsigned long*)UdmRealloc(s->astack, s->mastack * sizeof(unsigned long));
 	}
 }
 
@@ -82,7 +82,7 @@ static void PUSHCMD(UDM_BOOLSTACK * s,int arg){
 	s->ncstack++;
 	if (s->ncstack >= s->mcstack) {
 	  s->mcstack += UDM_MAXSTACK;
-	  s->cstack = (int*)realloc(s->cstack, s->mcstack * sizeof(int));
+	  s->cstack = (int*)UdmRealloc(s->cstack, s->mcstack * sizeof(int));
 	}
 }
 
@@ -133,8 +133,8 @@ int UdmCalcBoolItems(UDM_STACK_ITEM * items, size_t nitems, size_t *count){
 	s.ncstack=0;
 	s.nastack=0;
 	s.mcstack = s.mastack = UDM_MAXSTACK;
-	s.cstack = (int*)malloc(UDM_MAXSTACK * sizeof(int));
-	s.astack = (unsigned long*)malloc(UDM_MAXSTACK * sizeof(unsigned long));
+	s.cstack = (int*)UdmMalloc(UDM_MAXSTACK * sizeof(int));
+	s.astack = (unsigned long*)UdmMalloc(UDM_MAXSTACK * sizeof(unsigned long));
 
 
 #ifdef DEBUG_BOOL
