@@ -44,13 +44,14 @@
 
 #include "udm_common.h"
 #include "udm_socket.h"
-#include "udm_host.h"   
-#include "udm_utils.h"   
-#include "udm_ftp.h"   
-#include "udm_log.h"   
-#include "udm_proto.h"   
-#include "udm_xmalloc.h"   
-#include "udm_conf.h"   
+#include "udm_host.h"
+#include "udm_utils.h"
+#include "udm_ftp.h"
+#include "udm_log.h"
+#include "udm_proto.h"
+#include "udm_xmalloc.h"
+#include "udm_conf.h"
+#include "udm_vars.h"
 
 /*#define DEBUG_FTP*/
 
@@ -83,7 +84,7 @@ int Udm_ftp_read_line(UDM_CONN *connp){
 	return 0;
 }
 
-int Udm_ftp_connect(UDM_ENV * Conf,UDM_CONN *connp, char *hostname, int port, char *user, 
+int Udm_ftp_connect(UDM_ENV * Conf,UDM_CONN *connp, const char *hostname, int port, char *user, 
 		char *passwd, int timeout){
 	size_t len;
 	
@@ -318,7 +319,7 @@ int Udm_ftp_login(UDM_CONN *connp, char *user, char *passwd){
 
 static int ftp_parse_list(UDM_DOCUMENT *Doc){
 	UDM_CONN *connp = Doc->connp.connp;
-	char *path = UDM_NULL2EMPTY(Doc->CurURL.path);
+	const char *path = UDM_NULL2EMPTY(Doc->CurURL.path);
 	char *line, *buf_in, *ch, *buf_out, *tok, *fname;
         int len_h, len_f,len_p, i;
 	char *dir;
@@ -537,7 +538,7 @@ int Udm_ftp_set_binary(UDM_CONN *c){
 	return 0;
 }
 
-int Udm_ftp_cwd(UDM_CONN *c, char *path){
+int Udm_ftp_cwd(UDM_CONN *c, const char *path){
 	char *cmd;
 	int code;
 	size_t len;
