@@ -40,7 +40,7 @@
 
 /*#define DEBUG_GUESSER*/
 
-static UDM_LANGMAP *FindLangMap(UDM_LANGMAPLIST *L, char *lang, char *charset, char *filename) {
+static UDM_LANGMAP *FindLangMap(UDM_LANGMAPLIST *L, const char *lang, const char *charset, const char *filename) {
   UDM_LANGMAP *o = NULL;
   register size_t i;
 
