@@ -129,7 +129,7 @@ static char* get_id3(UDM_DOCUMENT *Doc){
 		
 		if (!strncmp(ch , "TPE1", 4)){
 			ch +=10;
-			artist = malloc(len+1);
+			artist = UdmMalloc(len+1);
 			udm_snprintf(artist, len, "%s", ch+1);
 			artist[len]='\0';
 			UdmRTrim(artist," ");
@@ -137,7 +137,7 @@ static char* get_id3(UDM_DOCUMENT *Doc){
 					break;
 		}else if(!strncmp(ch , "TALB", 4)){
 			ch +=10;
-			album = malloc(len+1);
+			album = UdmMalloc(len+1);
 			udm_snprintf(album, len, "%s", ch+1);
 			album[len]='\0';
 			UdmRTrim(album," ");
@@ -145,7 +145,7 @@ static char* get_id3(UDM_DOCUMENT *Doc){
 				break;
 		}else if(!strncmp(ch , "TIT2", 4) ){
 			ch +=10;
-			songname = malloc(len+1);
+			songname = UdmMalloc(len+1);
 			udm_snprintf(songname, len, "%s", ch+1);
 			songname[len]='\0';
 			UdmRTrim(songname," ");
@@ -159,9 +159,9 @@ static char* get_id3(UDM_DOCUMENT *Doc){
 		ch +=frame_size;
 	}
 	
-	if (!artist) artist = (char*)strdup("");
-	if (!album) album = (char*)strdup("");
-	if (!songname) songname = (char*)strdup("");
+	if (!artist) artist = (char*)UdmStrdup("");
+	if (!album) album = (char*)UdmStrdup("");
+	if (!songname) songname = (char*)UdmStrdup("");
 	
 	strcpy(name,"MP3.Song");
 	add_var(Doc,name,songname);
