@@ -158,7 +158,7 @@ int main(int argc, char **argv) {
 	  }
 	  exit(1);
 	}
-	sys_int=UdmGetCharSet("sys-int");
+	sys_int= &udm_charset_sys_int;
 
 	UdmConvInit(&fc_uni, CH_F, sys_int, (html_from) ? UDM_RECODE_HTML : 0);
 	UdmConvInit(&uni_tc, sys_int, CH_T, (html_to) ? UDM_RECODE_HTML : 0);
