@@ -50,14 +50,18 @@ __C_LINK int __UDMCALL UdmMirrorGET(UDM_AGENT *Indexer, UDM_DOCUMENT *Doc, UDM_U
      int       mirror_period=UdmVarListFindInt(&Doc->Sections,"MirrorPeriod",-1);
      const char     *mirror_data=UdmVarListFindStr(&Doc->Sections,"MirrorRoot",NULL);
      const char     *mirror_hdrs=UdmVarListFindStr(&Doc->Sections,"MirrorHeadersRoot",NULL);
-     
+
      Doc->Buf.size=0;
      nowtime = time(NULL);
      
      if(mirror_period <= 0)return(UDM_MIRROR_NOT_FOUND);
      
      /* MirrorRoot is not specified, nothing to do */
-     if(mirror_data == NULL) return(UDM_MIRROR_NOT_FOUND);
+     if (!mirror_data)
+     {
+       UdmLog(Indexer, UDM_LOG_ERROR, "MirrorGet: MirrorRoot is not set");
+       return UDM_MIRROR_NOT_FOUND;
+     }
      
      str_len = 128 + strlen(mirror_data) + ((mirror_hdrs) ? strlen(mirror_hdrs) : 0) + strlen(UDM_NULL2EMPTY(url->schema)) +
        strlen(UDM_NULL2EMPTY(url->hostname)) + strlen(UDM_NULL2EMPTY(url->path)) + 
@@ -131,6 +135,12 @@ __C_LINK int __UDMCALL UdmMirrorPUT(UDM_AGENT *Indexer, UDM_DOCUMENT *Doc, UDM_U
      const char     *mirror_hdrs=UdmVarListFindStr(&Doc->Sections,"MirrorHeadersRoot",NULL);
      char            *token, savechar;
      
+     if (!mirror_data)
+     {
+       UdmLog(Indexer, UDM_LOG_ERROR, "MirrorPUT: MirrorRoot is not set");
+       return UDM_ERROR;
+     }
+
      /* Cut HTTP response header first        */
      for(token = Doc->Buf.buf; *token; token++){
           if(!strncmp(token, "\r\n\r\n", 4)){
