@@ -307,7 +307,7 @@ static int UdmHTTPSGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc)
        return(fd);
 
     SSLeay_add_ssl_algorithms();
-    meth = SSLv2_client_method();
+    meth = SSLv23_client_method();
     SSL_load_error_strings();
 
     if ((ctx = SSL_CTX_new (meth))==NULL){
@@ -1170,24 +1170,97 @@ static int UdmNNTPGet(UDM_AGENT * Indexer,UDM_DOCUMENT *Doc){
 
 
 #ifdef USE_FILE
+static int cmpdirent (char **a1, char **a2) {
+  return(strcmp(*a1, *a2));
+}
+
+static void freedir (char **dir) {
+	char **p;
+
+	if (! dir) return;
+	for (p = dir; *p; p++) UdmFree(*p);
+	UdmFree(dir);
+}
+
+static char **loaddir (const char *path, int sort) {
+  struct dirent *buf;
+  char **_, **tmp;
+  size_t nrecs = 0, arecs = 32;
+  DIR *dir;
+
+  if (! path) return(NULL);
+
+  dir = opendir(path);
+  if (! dir) return(NULL);
+  _ = UdmMalloc(arecs * sizeof(char *));
+  if (! _) {
+    closedir(dir);
+    return(NULL);
+  }
+
+  while ((buf = readdir(dir))) {
+    if (arecs <= nrecs + 1) {
+      arecs += 32;
+      tmp = UdmRealloc(_, arecs * sizeof(char *));
+      if (! tmp) {
+        closedir(dir);
+	_[nrecs] = NULL;
+	freedir(_);
+	return(NULL);
+      }
+      _ = tmp;
+    }
+
+    _[nrecs++] = UdmStrdup(buf->d_name);
+  }
+
+  closedir(dir);
+
+  if (sort) UdmSort(_, nrecs, sizeof(char *), (qsort_cmp)cmpdirent);
+  _[nrecs] = NULL;
+  return(_);
+}
+
 static int UdmFILEGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
 	int fd,size,l,status=0,is_dir;
 	struct stat sb,sb1;
-	DIR * dir;
-	struct dirent *rec;
-	char filename[1024];
-	char newfilename[1024];
-	char openname[1024];
-	char mystatname[1024];
-	char command[32]="";
-	char proto[32]="";
-	char *lt,*s;
+	char filename[4096] = "";
+	char newfilename[4096];
+	char openname[4096];
+	char mystatname[4096];
+	char *lt,*s, *e;
+	const char *hostname;
 	time_t ims=0;
 	int  cvs_ignore= Indexer->Conf->CVS_ignore;
 
 	Doc->Buf.size=0;
-	sscanf(Doc->Buf.buf,"%s%s%s",command,filename,proto);
-	strcpy(newfilename,filename);
+	hostname= UdmVarListFindStr(&Doc->RequestHeaders,"Host",NULL);
+	if (hostname && (hostname[0] == '\0' || !strcasecmp(hostname, "localhost")))
+	  hostname= NULL;
+
+        for (s = Doc->Buf.buf; *s && *s != ' '; s++);
+        if (*s == ' ')
+        {
+          s++;
+          for (e = s; *e && *e != ' '; e++);
+          if (*e == ' ' && e - s < sizeof(filename))
+          {
+            memcpy(filename, s, e - s);
+            filename[e - s] = 0;
+          }
+        }
+
+        if (! *filename)
+        {
+          sprintf(Doc->Buf.buf,"HTTP/1.0 500 %s\r\nX-Reason: bad file\r\n\r\n",UdmHTTPErrMsg(500));
+          Doc->Buf.size=strlen(Doc->Buf.buf);
+          return 0;
+        }
+
+	udm_snprintf(newfilename, sizeof(newfilename), "%s%s%s",
+		         hostname ? "//" : "",
+				 hostname ? hostname : "",
+		         filename);
 	UdmUnescapeCGIQuery(openname,newfilename);
 
 #ifdef WIN32
@@ -1210,10 +1283,14 @@ static int UdmFILEGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
 	strcpy(mystatname,openname);
 
 #ifdef WIN32
-	/* Remove traling slash sign stat("c:\a\") doesn't work  */
-	/* under win. We'll pass stat("c:\a") instead            */
-	/* In other hand when only drive name is checked it must */
-	/* have traling slash:  stat("c:\");                     */
+	/*
+	  Remove traling slash sign stat("c:\a\") doesn't work
+	  under win. We'll pass stat("c:\a") instead
+	  In other hand when only drive name is checked it must
+	  have traling slash:  stat("c:\");
+	  For a network resouce we should execute WITH trailing
+	  slash, i.e. stat("\\servername\resoucename\");
+	*/
 	{
 		int len;
 		
@@ -1223,7 +1300,7 @@ static int UdmFILEGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
 			if(*s=='/')*s='\\';
 			s++;
 		}
-		if ((len>3)&&(mystatname[len-1]=='\\'))
+		if ((len>3) && (mystatname[len-1]=='\\') && !hostname)
 			mystatname[len-1]='\0';
 	}
 #endif
@@ -1249,23 +1326,28 @@ static int UdmFILEGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
 	}
 	
 	if(sb.st_mode&S_IFDIR){
+		char **recs = loaddir(openname, 1);
+		size_t rpos;
 
-		if((dir=opendir(openname))){
+/*		if((dir=opendir(openname))){ */
+		if (recs) {
 			char *stre;
 			strcpy(Doc->Buf.buf,"HTTP/1.0 200 OK\r\nContent-type: text/html\r\n\r\n<HTML><BODY>\n");
 			
 			stre=UDM_STREND(Doc->Buf.buf);
-			while((rec = readdir (dir))){
+/*			while((rec = readdir (dir))){ */
+			for (rpos = 0; recs[rpos]; rpos++) {
 				char escaped_name[1024]="";
-				char *src,*e;
+				char *src;
+
 				/*
 				This does not work on Solaris
 				is_dir=(rec->d_type==DT_DIR);
 				*/
-				if (cvs_ignore && !strcmp(rec->d_name,"CVS"))
+				if (cvs_ignore && !strcmp(recs[rpos],"CVS"))
 					continue;
 				
-				sprintf(newfilename, "%s%s", openname, rec->d_name);
+				sprintf(newfilename, "%s%s", openname, recs[rpos]);
 
 #ifndef WIN32
 				if (! lstat(newfilename, &sb1) &&
@@ -1282,8 +1364,8 @@ static int UdmFILEGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
 				}
 
 				e=escaped_name;
-				for(src=rec->d_name;*src;src++){
-					if(strchr(" %&<>+[](){}/?#'\"\\;,",*src)){
+				for(src=recs[rpos];*src;src++){
+					if(strchr(" %&<>+[](){}/?#'\"\\;,`",*src)){
 						sprintf(e,"%%%X",(int)*src);
 						e+=3;
 					}else{
@@ -1302,7 +1384,8 @@ static int UdmFILEGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
 				  stre=UDM_STREND(e);
 				}
 			}
-			closedir(dir);
+/*			closedir(dir); */
+			freedir(recs);
 			strcpy(UDM_STREND(Doc->Buf.buf),"</BODY><HTML>\n");
 			Doc->Buf.size=strlen(Doc->Buf.buf);
 			return 0;
@@ -1361,9 +1444,9 @@ static int UdmFILEGet(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
 static int UdmBuildHTTPRequest(UDM_DOCUMENT *Doc){
 	const char	*method=(Doc->method==UDM_METHOD_HEAD)?"HEAD":"GET";
 	const char	*proxy=UdmVarListFindStr(&Doc->RequestHeaders,"Proxy",NULL);
-	size_t		i;
-	char            *url = (char*)UdmMalloc((i = strlen(UDM_NULL2EMPTY(Doc->CurURL.path)) + 
-					      strlen(UDM_NULL2EMPTY(Doc->CurURL.filename)) + 1));
+	size_t		i = strlen(UDM_NULL2EMPTY(Doc->CurURL.path)) + 
+					strlen(UDM_NULL2EMPTY(Doc->CurURL.filename)) + 1;
+	char            *url = (char*)UdmMalloc(i);
 	char            *eurl = (char*)UdmMalloc(3 * i);
 
 	if (url == NULL || eurl == NULL) return UDM_ERROR;
