@@ -50,6 +50,11 @@ void __UDMCALL UdmResultFree(UDM_RESULT * Res){
 	UDM_FREE(Res->items);
 	UDM_FREE(Res->PerSite);
 	UDM_FREE(Res->CoordList.Coords);
+	for (i = 0; i < Res->CoordList.ncoords; i++)
+	{
+	  UDM_FREE(Res->CoordList.Data[i].url);
+          UDM_FREE(Res->CoordList.Data[i].section);
+	}
 	UDM_FREE(Res->CoordList.Data);
 	UdmWideWordListFree(&Res->WWList);
 	if(Res->Doc){
