@@ -40,10 +40,10 @@ UDM_ROBOT* UdmRobotFind(UDM_ROBOTS *Robots,const char *hostinfo){
 	return(NULL);
 }
 
-static UDM_ROBOT* DeleteRobotRules(UDM_ROBOTS *Robots,char *hostinfo){
+static UDM_ROBOT* DeleteRobotRules(UDM_ROBOTS *Robots,const char *hostinfo){
 	UDM_ROBOT *robot;
 	size_t i;
-	
+
 	if((robot=UdmRobotFind(Robots, hostinfo))!=NULL){
 		for(i=0;i<robot->nrules;i++){
 			UDM_FREE(robot->Rule[i].path);
@@ -55,7 +55,7 @@ static UDM_ROBOT* DeleteRobotRules(UDM_ROBOTS *Robots,char *hostinfo){
 	return(NULL);
 }
 
-UDM_ROBOT* UdmRobotAddEmpty(UDM_ROBOTS *Robots,char *hostinfo){
+UDM_ROBOT* UdmRobotAddEmpty(UDM_ROBOTS *Robots,const char *hostinfo){
 	Robots->Robot = (UDM_ROBOT*)UdmRealloc(Robots->Robot, (Robots->nrobots + 1) * sizeof(UDM_ROBOT));
 	if(Robots->Robot==NULL) {
 	  Robots->nrobots = 0;
@@ -69,7 +69,7 @@ UDM_ROBOT* UdmRobotAddEmpty(UDM_ROBOTS *Robots,char *hostinfo){
 	return(&Robots->Robot[Robots->nrobots-1]);
 }
 
-static int AddRobotRule(UDM_ROBOT *robot,int cmd,char *path){
+static int AddRobotRule(UDM_ROBOT *robot,int cmd,const char *path){
 	robot->Rule = (UDM_ROBOT_RULE*)UdmRealloc(robot->Rule, (robot->nrules + 1) * sizeof(UDM_ROBOT_RULE));
 	if(robot->Rule==NULL) {
 	  robot->nrules = 0;
@@ -105,10 +105,17 @@ UDM_ROBOT_RULE* UdmRobotRuleFind(UDM_ROBOTS *Robots,UDM_URL *URL){
 	UDM_ROBOT *robot;
 	size_t j;
 	
-	if((robot=UdmRobotFind(Robots, URL->hostinfo))!=NULL){
+	if((robot=UdmRobotFind(Robots, UDM_NULL2EMPTY(URL->hostinfo)))!=NULL){
+                const char *specific;
+
+                if (! URL->specific ||
+                    ! URL->specific[0] ||
+                    ! URL->specific[1] ||
+                    ! (specific = strchr(URL->specific + 2, '/'))) specific = "/";
+
 		for(j=0;j<robot->nrules;j++){
 			/* FIXME: compare full URL */
-			if(!strncmp(URL->path,robot->Rule[j].path,strlen(robot->Rule[j].path))){
+			if(!strncmp(specific,robot->Rule[j].path,strlen(robot->Rule[j].path))){
 				if(robot->Rule[j].cmd!=UDM_METHOD_DISALLOW) return(NULL);
 				else return(&robot->Rule[j]);
 			}
@@ -117,7 +124,7 @@ UDM_ROBOT_RULE* UdmRobotRuleFind(UDM_ROBOTS *Robots,UDM_URL *URL){
 	return(NULL);
 }
 
-int UdmRobotParse(UDM_AGENT *Indexer, UDM_SERVER *Srv, char *content, char *hostinfo) {
+int UdmRobotParse(UDM_AGENT *Indexer, UDM_SERVER *Srv, char *content, const char *hostinfo) {
         UDM_ENV *Conf = Indexer->Conf;
         UDM_ROBOTS *Robots = &Conf->Robots;
 	UDM_ROBOT *robot;
