@@ -83,7 +83,7 @@ static ssize_t UdmSearchdSendPacket(int fd,const UDM_SEARCHD_PACKET_HEADER *hdr,
 #define INADDR_NONE ((unsigned long) -1)
 #endif
 
-static int open_host(char *hostname,int port, int timeout)
+static int open_host(const char *hostname,int port, int timeout)
 {
 	int net;
 	struct hostent *host;
@@ -118,9 +118,11 @@ static int open_host(char *hostname,int port, int timeout)
 
 int UdmSearchdConnect(UDM_DB *cl){
 	int res=UDM_OK;
-	
-	cl->searchd = open_host(cl->addr.hostname, cl->addr.port ? cl->addr.port : UDM_SEARCHD_PORT, 0);
-	if(cl->searchd<=0){
+	const char* hostname= UdmVarListFindStr(&cl->Vars, "DBHost", "localhost");
+	int port= UdmVarListFindInt(&cl->Vars, "DBPort", UDM_SEARCHD_PORT);
+	cl->searchd = open_host(hostname, port, 0);
+	if(cl->searchd<=0)
+	{
 		cl->searchd=0;
 /*		UdmLog(query, UDM_LOG_ERROR, "Can't connect to searchd at '%s:%d'", host, port);*/
 		res=UDM_ERROR;
@@ -145,7 +147,7 @@ void UdmSearchdClose(UDM_DB *cl) {
 int __UDMCALL UdmResAddDocInfoSearchd(UDM_AGENT * query,UDM_DB *cl,UDM_RESULT * Res,size_t clnum){
 	UDM_SEARCHD_PACKET_HEADER hdr;
 	char * msg=NULL;
-	size_t i,num=0,curnum=0;
+	size_t i /* ,num=0,curnum=0 */;
 	int done = 0;
 	ssize_t nsent,nrecv;
 	char * dinfo=NULL;
@@ -170,7 +172,7 @@ int __UDMCALL UdmResAddDocInfoSearchd(UDM_AGENT * query,UDM_DB *cl,UDM_RESULT *
 	  ulen = strlen(textbuf)+2;
 	  olen = dlen;
 	  dlen = dlen + ulen;
-	  dinfo = (char*)realloc(dinfo, dlen + 1);
+	  dinfo = (char*)UdmRealloc(dinfo, dlen + 1);
 	  dinfo[olen] = '\0';
 	  sprintf(dinfo + olen, "%s\r\n", textbuf);
 	}
@@ -193,7 +195,7 @@ int __UDMCALL UdmResAddDocInfoSearchd(UDM_AGENT * query,UDM_DB *cl,UDM_RESULT *
 		}
 		switch(hdr.cmd){
 			case UDM_SEARCHD_CMD_ERROR:
-				msg=(char*)malloc(hdr.len+1); /* Add checking */
+				msg=(char*)UdmMalloc(hdr.len+1); /* Add checking */
 				nrecv=UdmRecvall(cl->searchd,msg,hdr.len);
 				msg[nrecv]='\0';
 				sprintf(query->Conf->errstr,"Searchd error: '%s'",msg);
@@ -202,7 +204,7 @@ int __UDMCALL UdmResAddDocInfoSearchd(UDM_AGENT * query,UDM_DB *cl,UDM_RESULT *
 				done=1;
 				break;
 			case UDM_SEARCHD_CMD_MESSAGE:
-				msg=(char*)malloc(hdr.len+1); /* Add checking */
+				msg=(char*)UdmMalloc(hdr.len+1); /* Add checking */
 				nrecv=UdmRecvall(cl->searchd,msg,hdr.len);
 				msg[nrecv]='\0';
 #ifdef DEBUG_SDP
@@ -211,7 +213,7 @@ int __UDMCALL UdmResAddDocInfoSearchd(UDM_AGENT * query,UDM_DB *cl,UDM_RESULT *
 				UDM_FREE(msg);
 				break;
 			case UDM_SEARCHD_CMD_DOCINFO:
-				dinfo = (char*)realloc(dinfo, hdr.len + 1);
+				dinfo = (char*)UdmRealloc(dinfo, hdr.len + 1);
 				nrecv=UdmRecvall(cl->searchd,dinfo,hdr.len);
 				dinfo[hdr.len]='\0';
 #ifdef DEBUG_SDP
@@ -288,7 +290,7 @@ static UDM_URL_CRD *UdmSearchdGetWordResponse(UDM_AGENT *query,UDM_RESULT *Res,U
 #endif
 		switch(hdr.cmd){
 			case UDM_SEARCHD_CMD_ERROR:
-				msg=(char*)malloc(hdr.len+1); /* Add checking */
+				msg=(char*)UdmMalloc(hdr.len+1); /* Add checking */
 				nrecv=UdmRecvall(cl->searchd,msg,hdr.len);
 				msg[nrecv]='\0';
 				sprintf(query->Conf->errstr,"Searchd error: '%s'",msg);
@@ -297,7 +299,7 @@ static UDM_URL_CRD *UdmSearchdGetWordResponse(UDM_AGENT *query,UDM_RESULT *Res,U
 				done=1;
 				break;
 			case UDM_SEARCHD_CMD_MESSAGE:
-				msg=(char*)malloc(hdr.len+1); /* Add checking */
+				msg=(char*)UdmMalloc(hdr.len+1); /* Add checking */
 				nrecv=UdmRecvall(cl->searchd,msg,hdr.len);
 				msg[nrecv]='\0';
 #ifdef DEBUG_SDP
@@ -307,7 +309,7 @@ static UDM_URL_CRD *UdmSearchdGetWordResponse(UDM_AGENT *query,UDM_RESULT *Res,U
 				break;
 			case UDM_SEARCHD_CMD_WORDS:
 				UDM_FREE(wrd);
-				wrd=(UDM_URL_CRD*)malloc(hdr.len + 1); /* FIXME: add checking */
+				wrd=(UDM_URL_CRD*)UdmMalloc(hdr.len + 1); /* FIXME: add checking */
 				nrecv=UdmRecvall(cl->searchd,wrd,hdr.len);
 				Res->total_found=hdr.len/sizeof(*wrd);
 #ifdef DEBUG_SDP
@@ -316,14 +318,14 @@ static UDM_URL_CRD *UdmSearchdGetWordResponse(UDM_AGENT *query,UDM_RESULT *Res,U
 				done=1;
 				break;
 		        case UDM_SEARCHD_CMD_PERSITE:
-			        Res->PerSite = (size_t*)malloc(hdr.len + 1);
+			        Res->PerSite = (size_t*)UdmMalloc(hdr.len + 1);
 				nrecv = UdmRecvall(cl->searchd, Res->PerSite, hdr.len);
 #ifdef DEBUG_SDP
 				fprintf(stderr, "Received PerSite size=%d nwrd=%d\n",hdr.len,Res->total_found);
 #endif
 				break;
 		        case UDM_SEARCHD_CMD_DATA:
-			        Res->CoordList.Data = (UDM_URLDATA*)malloc(hdr.len + 1);
+			        Res->CoordList.Data = (UDM_URLDATA*)UdmMalloc(hdr.len + 1);
 				nrecv = UdmRecvall(cl->searchd, Res->CoordList.Data, hdr.len);
 #ifdef DEBUG_SDP
 				fprintf(stderr, "Received URLDATA size=%d nwrd=%d\n", hdr.len, Res->total_found);
@@ -375,13 +377,13 @@ int __UDMCALL UdmFindWordsSearchd(UDM_AGENT *query,UDM_RESULT *Res, UDM_DB *sear
 	const char *df = UdmVarListFindStr(&query->Conf->Vars, "DateFormat", NULL);
 	int		res=UDM_OK;
 
-	if (NULL==(request=(char*)malloc(maxlen))) {
+	if (NULL==(request=(char*)UdmMalloc(maxlen))) {
 		sprintf(query->Conf->errstr,"Can't allocate memory");
 		return UDM_ERROR;
 	}
 	
 	if (df) {
-	  edf = (char*)malloc(strlen(df) * 10);
+	  edf = (char*)UdmMalloc(strlen(df) * 10);
 	  UdmEscapeURL(edf, df);
 	}
 
@@ -419,7 +421,7 @@ int __UDMCALL UdmSearchdCatAction(UDM_AGENT *A, UDM_CATEGORY *C, int cmd, void *
 	hdr.cmd = UDM_SEARCHD_CMD_CATINFO;
 	hdr.len = sizeof(int) + strlen(C->addr) + 1;
 	
-	if ((buf = (char*)malloc(hdr.len)) == NULL) {
+	if ((buf = (char*)UdmMalloc(hdr.len)) == NULL) {
 	  UdmLog(A, UDM_LOG_ERROR, "Out of memory");
 	  return UDM_ERROR;
 	}
@@ -445,7 +447,7 @@ int __UDMCALL UdmSearchdCatAction(UDM_AGENT *A, UDM_CATEGORY *C, int cmd, void *
 		}
 		switch(hdr.cmd){
 			case UDM_SEARCHD_CMD_ERROR:
-				msg = (char*)malloc(hdr.len + 1); /* Add checking */
+				msg = (char*)UdmMalloc(hdr.len + 1); /* Add checking */
 				nrecv = UdmRecvall(searchd->searchd, msg, hdr.len);
 				msg[nrecv] = '\0';
 				sprintf(A->Conf->errstr, "Searchd error: '%s'", msg);
@@ -454,7 +456,7 @@ int __UDMCALL UdmSearchdCatAction(UDM_AGENT *A, UDM_CATEGORY *C, int cmd, void *
 				done=1;
 				break;
 			case UDM_SEARCHD_CMD_MESSAGE:
-				msg=(char*)malloc(hdr.len+1); /* Add checking */
+				msg=(char*)UdmMalloc(hdr.len+1); /* Add checking */
 				nrecv = UdmRecvall(searchd->searchd, msg, hdr.len);
 				msg[nrecv] = '\0';
 #ifdef DEBUG_SDP
@@ -463,7 +465,7 @@ int __UDMCALL UdmSearchdCatAction(UDM_AGENT *A, UDM_CATEGORY *C, int cmd, void *
 				UDM_FREE(msg);
 				break;
 			case UDM_SEARCHD_CMD_CATINFO:
-			        dinfo=(char*)malloc(hdr.len+1);
+			        dinfo=(char*)UdmMalloc(hdr.len+1);
 				nrecv=UdmRecvall(searchd->searchd, dinfo, hdr.len);
 				dinfo[hdr.len]='\0';
 #ifdef DEBUG_SDP
@@ -510,7 +512,7 @@ int __UDMCALL UdmSearchdURLAction(UDM_AGENT *A, UDM_DOCUMENT *D, int cmd, void *
 	hdr.cmd = UDM_SEARCHD_CMD_URLACTION;
 	hdr.len = sizeof(int);
 	
-	if ((buf = (char*)malloc(hdr.len)) == NULL) {
+	if ((buf = (char*)UdmMalloc(hdr.len)) == NULL) {
 	  UdmLog(A, UDM_LOG_ERROR, "Out of memory");
 	  return UDM_ERROR;
 	}
@@ -535,7 +537,7 @@ int __UDMCALL UdmSearchdURLAction(UDM_AGENT *A, UDM_DOCUMENT *D, int cmd, void *
 		}
 		switch(hdr.cmd){
 			case UDM_SEARCHD_CMD_ERROR:
-				msg = (char*)malloc(hdr.len + 1); /* Add checking */
+				msg = (char*)UdmMalloc(hdr.len + 1); /* Add checking */
 				nrecv = UdmRecvall(searchd->searchd, msg, hdr.len);
 				msg[nrecv] = '\0';
 				sprintf(A->Conf->errstr, "Searchd error: '%s'", msg);
@@ -544,7 +546,7 @@ int __UDMCALL UdmSearchdURLAction(UDM_AGENT *A, UDM_DOCUMENT *D, int cmd, void *
 				done=1;
 				break;
 			case UDM_SEARCHD_CMD_MESSAGE:
-				msg=(char*)malloc(hdr.len+1); /* Add checking */
+				msg=(char*)UdmMalloc(hdr.len+1); /* Add checking */
 				nrecv = UdmRecvall(searchd->searchd, msg, hdr.len);
 				msg[nrecv] = '\0';
 #ifdef DEBUG_SDP
@@ -553,7 +555,7 @@ int __UDMCALL UdmSearchdURLAction(UDM_AGENT *A, UDM_DOCUMENT *D, int cmd, void *
 				UDM_FREE(msg);
 				break;
 			case UDM_SEARCHD_CMD_DOCCOUNT:
-			        dinfo=(char*)malloc(hdr.len+1);
+			        dinfo=(char*)UdmMalloc(hdr.len+1);
 				nrecv=UdmRecvall(searchd->searchd, dinfo, hdr.len);
 				dinfo[hdr.len]='\0';
 
@@ -600,7 +602,7 @@ int UdmCloneListSearchd(UDM_AGENT *Indexer, UDM_DOCUMENT *Doc, UDM_RESULT *Res,
 		}
 		switch(hdr.cmd){
 			case UDM_SEARCHD_CMD_ERROR:
-				msg = (char*)malloc(hdr.len + 1); /* Add checking */
+				msg = (char*)UdmMalloc(hdr.len + 1); /* Add checking */
 				nrecv = UdmRecvall(db->searchd, msg, hdr.len);
 				msg[nrecv] = '\0';
 				sprintf(Indexer->Conf->errstr, "Searchd error: '%s'", msg);
@@ -609,19 +611,20 @@ int UdmCloneListSearchd(UDM_AGENT *Indexer, UDM_DOCUMENT *Doc, UDM_RESULT *Res,
 				done = 1;
 				break;
 			case UDM_SEARCHD_CMD_DOCINFO:
-				dinfo = (char*)malloc(hdr.len + 1);
+				dinfo = (char*)UdmMalloc(hdr.len + 1);
 				nrecv = UdmRecvall(db->searchd, dinfo, hdr.len);
 				dinfo[hdr.len] = '\0';
 #ifdef DEBUG_SDP
 				UdmLog(Indexer, UDM_LOG_DEBUG, "Received DOCINFO size=%d buf=%s\n", hdr.len, dinfo);
 #endif				
-				tok = udm_strtok_r(dinfo, "\r\n", &lt);
+				if (strcmp(dinfo, "nocloneinfo")) tok = udm_strtok_r(dinfo, "\r\n", &lt);
+				else tok = NULL;
 				
 				while(tok){
 					UDM_DOCUMENT *D;
 					size_t nd = Res->num_rows++;
 
-					Res->Doc = (UDM_DOCUMENT*)realloc(Res->Doc, (Res->num_rows) * sizeof(UDM_DOCUMENT));
+					Res->Doc = (UDM_DOCUMENT*)UdmRealloc(Res->Doc, (Res->num_rows) * sizeof(UDM_DOCUMENT));
 					if (Res->Doc == NULL) {
 					  sprintf(Indexer->Conf->errstr, "Realloc error");
 					  rc = UDM_ERROR;
