@@ -16,17 +16,36 @@
 */
 
 #include "udm_config.h"
-#include "udm_utils.h"
 #include <string.h>
 
 #include "udm_uniconv.h"
+#include "udm_unidata.h"
 #include "uconv-8bit.h"
+#include "udm_utils.h"
+
+
+#define lcase_mb   UdmStrToLower
+#define lcase_8bit UdmStrToLower8bit
+
+
+UDM_CHARSET udm_charset_sys_int=
+{
+  UDM_CHARSET_SYS_INT,
+  udm_mb_wc_sys_int,
+  udm_wc_mb_sys_int,
+  lcase_mb,
+  "sys-int",
+  UDM_CHARSET_UNICODE,
+  NULL,
+  NULL
+};
 
 static UDM_CHARSET built_charsets[]={
 {
   UDM_CHARSET_8859_1,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-1",
   UDM_CHARSET_WESTERN,
   tab_8859_1_uni,
@@ -36,6 +55,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_10,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-10",
   UDM_CHARSET_NORDIC,
   tab_8859_10_uni,
@@ -45,6 +65,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_11,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-11",
   UDM_CHARSET_THAI,
   tab_8859_11_uni,
@@ -54,6 +75,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_13,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-13",
   UDM_CHARSET_BALTIC,
   tab_8859_13_uni,
@@ -63,6 +85,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_14,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-14",
   UDM_CHARSET_CELTIC,
   tab_8859_14_uni,
@@ -72,6 +95,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_15,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-15",
   UDM_CHARSET_WESTERN,
   tab_8859_15_uni,
@@ -81,6 +105,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_16,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-16",
   UDM_CHARSET_CENTRAL,
   tab_8859_16_uni,
@@ -90,6 +115,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_2,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-2",
   UDM_CHARSET_CENTRAL,
   tab_8859_2_uni,
@@ -99,6 +125,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_3,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-3",
   UDM_CHARSET_SOUTHERN,
   tab_8859_3_uni,
@@ -108,6 +135,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_4,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-4",
   UDM_CHARSET_BALTIC,
   tab_8859_4_uni,
@@ -117,6 +145,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_5,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-5",
   UDM_CHARSET_CYRILLIC,
   tab_8859_5_uni,
@@ -126,6 +155,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_6,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-6",
   UDM_CHARSET_ARABIC,
   tab_8859_6_uni,
@@ -135,6 +165,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_7,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-7",
   UDM_CHARSET_GREEK,
   tab_8859_7_uni,
@@ -144,6 +175,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_8,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-8",
   UDM_CHARSET_HEBREW,
   tab_8859_8_uni,
@@ -153,6 +185,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_8859_9,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "iso-8859-9",
   UDM_CHARSET_TURKISH,
   tab_8859_9_uni,
@@ -162,6 +195,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_ARMSCII_8,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "armscii-8",
   UDM_CHARSET_ARMENIAN,
   tab_armscii_8_uni,
@@ -171,7 +205,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1250,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1250",
+  lcase_8bit,
+  "windows-1250",
   UDM_CHARSET_CENTRAL,
   tab_cp1250_uni,
   idx_uni_cp1250
@@ -180,7 +215,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1251,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1251",
+  lcase_8bit,
+  "windows-1251",
   UDM_CHARSET_CYRILLIC,
   tab_cp1251_uni,
   idx_uni_cp1251
@@ -189,7 +225,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1252,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1252",
+  lcase_8bit,
+  "windows-1252",
   UDM_CHARSET_WESTERN,
   tab_cp1252_uni,
   idx_uni_cp1252
@@ -198,7 +235,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1253,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1253",
+  lcase_8bit,
+  "windows-1253",
   UDM_CHARSET_GREEK,
   tab_cp1253_uni,
   idx_uni_cp1253
@@ -207,7 +245,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1254,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1254",
+  lcase_8bit,
+  "windows-1254",
   UDM_CHARSET_TURKISH,
   tab_cp1254_uni,
   idx_uni_cp1254
@@ -216,7 +255,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1255,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1255",
+  lcase_8bit,
+  "windows-1255",
   UDM_CHARSET_HEBREW,
   tab_cp1255_uni,
   idx_uni_cp1255
@@ -225,7 +265,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1256,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1256",
+  lcase_8bit,
+  "windows-1256",
   UDM_CHARSET_ARABIC,
   tab_cp1256_uni,
   idx_uni_cp1256
@@ -234,7 +275,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1257,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1257",
+  lcase_8bit,
+  "windows-1257",
   UDM_CHARSET_BALTIC,
   tab_cp1257_uni,
   idx_uni_cp1257
@@ -243,7 +285,8 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP1258,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
-  "cp1258",
+  lcase_8bit,
+  "windows-1258",
   UDM_CHARSET_VIETNAMESE,
   tab_cp1258_uni,
   idx_uni_cp1258
@@ -252,6 +295,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP437,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp437",
   UDM_CHARSET_WESTERN,
   tab_cp437_uni,
@@ -261,6 +305,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP850,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp850",
   UDM_CHARSET_WESTERN,
   tab_cp850_uni,
@@ -270,6 +315,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP852,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp852",
   UDM_CHARSET_CENTRAL,
   tab_cp852_uni,
@@ -279,6 +325,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP855,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp855",
   UDM_CHARSET_CYRILLIC,
   tab_cp855_uni,
@@ -288,6 +335,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP857,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp857",
   UDM_CHARSET_TURKISH,
   tab_cp857_uni,
@@ -297,6 +345,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP860,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp860",
   UDM_CHARSET_WESTERN,
   tab_cp860_uni,
@@ -306,6 +355,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP861,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp861",
   UDM_CHARSET_ICELANDIC,
   tab_cp861_uni,
@@ -315,6 +365,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP862,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp862",
   UDM_CHARSET_HEBREW,
   tab_cp862_uni,
@@ -324,6 +375,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP863,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp863",
   UDM_CHARSET_WESTERN,
   tab_cp863_uni,
@@ -333,6 +385,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP864,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp864",
   UDM_CHARSET_ARABIC,
   tab_cp864_uni,
@@ -342,6 +395,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP865,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp865",
   UDM_CHARSET_NORDIC,
   tab_cp865_uni,
@@ -351,6 +405,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP866,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp866",
   UDM_CHARSET_CYRILLIC,
   tab_cp866_uni,
@@ -360,6 +415,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP869,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp869",
   UDM_CHARSET_GREEK,
   tab_cp869_uni,
@@ -369,6 +425,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_CP874,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "cp874",
   UDM_CHARSET_THAI,
   tab_cp874_uni,
@@ -378,6 +435,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_KOI8_R,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "koi8-r",
   UDM_CHARSET_CYRILLIC,
   tab_koi8_r_uni,
@@ -387,6 +445,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_KOI8_U,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "koi8-u",
   UDM_CHARSET_CYRILLIC,
   tab_koi8_u_uni,
@@ -396,6 +455,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACARABIC,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacArabic",
   UDM_CHARSET_ARABIC,
   tab_macarabic_uni,
@@ -405,6 +465,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACCE,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacCE",
   UDM_CHARSET_CENTRAL,
   tab_macce_uni,
@@ -414,6 +475,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACCROATIAN,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacCroatian",
   UDM_CHARSET_CENTRAL,
   tab_maccroatian_uni,
@@ -423,6 +485,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACCYRILLIC,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacCyrillic",
   UDM_CHARSET_CYRILLIC,
   tab_maccyrillic_uni,
@@ -432,6 +495,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACGREEK,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacGreek",
   UDM_CHARSET_GREEK,
   tab_macgreek_uni,
@@ -441,6 +505,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACHEBREW,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacHebrew",
   UDM_CHARSET_HEBREW,
   tab_machebrew_uni,
@@ -450,6 +515,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACICELAND,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacIceland",
   UDM_CHARSET_ICELANDIC,
   tab_maciceland_uni,
@@ -459,6 +525,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACROMAN,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacRoman",
   UDM_CHARSET_WESTERN,
   tab_macroman_uni,
@@ -468,6 +535,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACROMANIA,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacRomania",
   UDM_CHARSET_CENTRAL,
   tab_macromania_uni,
@@ -477,6 +545,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACTHAI,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacThai",
   UDM_CHARSET_THAI,
   tab_macthai_uni,
@@ -486,6 +555,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_MACTURKISH,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "MacTurkish",
   UDM_CHARSET_TURKISH,
   tab_macturkish_uni,
@@ -495,6 +565,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_US_ASCII,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "us-ascii",
   UDM_CHARSET_WESTERN,
   tab_us_ascii_uni,
@@ -504,6 +575,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_VISCII,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "viscii",
   UDM_CHARSET_VIETNAMESE,
   tab_viscii_uni,
@@ -513,6 +585,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_GEOSTD8,
   udm_mb_wc_8bit,
   udm_wc_mb_8bit,
+  lcase_8bit,
   "geostd8",
   UDM_CHARSET_GEORGIAN,
   tab_geostd8_uni,
@@ -522,6 +595,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_UTF8,
   udm_mb_wc_utf8,
   udm_wc_mb_utf8,
+  lcase_mb,
   "utf-8",
   UDM_CHARSET_UNICODE,
   NULL,
@@ -531,6 +605,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_SYS_INT,
   udm_mb_wc_sys_int,
   udm_wc_mb_sys_int,
+  lcase_mb,
   "sys-int",
   UDM_CHARSET_UNICODE,
   NULL,
@@ -542,6 +617,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_GB2312,
   udm_mb_wc_gb2312,
   udm_wc_mb_gb2312,
+  lcase_mb,
   "gb2312",
   UDM_CHARSET_CHINESE_SIMPLIFIED,
   NULL,
@@ -554,6 +630,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_BIG5,
   udm_mb_wc_big5,
   udm_wc_mb_big5,
+  lcase_mb,
   "big5",
   UDM_CHARSET_CHINESE_TRADITIONAL,
   NULL,
@@ -566,6 +643,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_SJIS,
   udm_mb_wc_sjis,
   udm_wc_mb_sjis,
+  lcase_mb,
   "Shift-JIS",
   UDM_CHARSET_JAPANESE,
   NULL,
@@ -578,6 +656,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_EUC_KR,
   udm_mb_wc_euc_kr,
   udm_wc_mb_euc_kr,
+  lcase_mb,
   "EUC-KR",
   UDM_CHARSET_KOREAN,
   NULL,
@@ -590,6 +669,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_EUC_JP,
   udm_mb_wc_euc_jp,
   udm_wc_mb_euc_jp,
+  lcase_mb,
   "EUC-JP",
   UDM_CHARSET_JAPANESE,
   NULL,
@@ -603,6 +683,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_GBK,
   udm_mb_wc_gbk,
   udm_wc_mb_gbk,
+  lcase_mb,
   "GBK",
   UDM_CHARSET_CHINESE_SIMPLIFIED,
   NULL,
@@ -615,6 +696,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_GUJARATI,
   udm_mb_wc_gujarati,
   udm_wc_mb_gujarati,
+  lcase_mb,
   "MacGujarati",
   UDM_CHARSET_INDIAN,
   NULL,
@@ -627,6 +709,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_TSCII,
   udm_mb_wc_tscii,
   udm_wc_mb_tscii,
+  lcase_mb,
   "tscii",
   UDM_CHARSET_INDIAN,
   NULL,
@@ -639,6 +722,7 @@ static UDM_CHARSET built_charsets[]={
   UDM_CHARSET_ISO2022JP,
   udm_mb_wc_iso2022jp,
   udm_wc_mb_iso2022jp,
+  lcase_mb,
   "iso-2022-jp",
   UDM_CHARSET_JAPANESE,
   NULL,
@@ -651,6 +735,7 @@ static UDM_CHARSET built_charsets[]={
   NULL,
   NULL,
   NULL,
+  NULL,
   0,
   NULL,
   NULL
@@ -659,11 +744,14 @@ static UDM_CHARSET built_charsets[]={
 };
 
 
-typedef struct {
-	const	char * name;
-	int   	id;
+typedef struct
+{
+  const	char *name;
+  int        id;
 } UDM_CHARSET_ALIAS;
 
+
+/* Must be in alphabetic order */
 static UDM_CHARSET_ALIAS alias[]={
 	{"437",			UDM_CHARSET_CP437},
 	{"850",			UDM_CHARSET_CP850},
@@ -931,46 +1019,51 @@ static UDM_CHARSET_ALIAS alias[]={
 	{"x-euc-jp",		UDM_CHARSET_EUC_JP},
 	{"x-mac-cyrillic",	UDM_CHARSET_MACCYRILLIC},
 	{"x-sjis",		UDM_CHARSET_SJIS},
-{NULL,0}};
+	{NULL,0}
+};
 
 
 
-__C_LINK UDM_CHARSET * __UDMCALL UdmGetCharSetByID(int id) {
+__C_LINK UDM_CHARSET * __UDMCALL UdmGetCharSetByID(int id)
+{
   UDM_CHARSET *c;
-
+  
   for (c=built_charsets; c->name; c++)
     if (c->id==id)
       return c;
   return NULL;
 }
 
-const char * UdmCharsetCanonicalName(const char * s){
-  UDM_CHARSET *c;
-
-  c=UdmGetCharSet(s);
+const char * UdmCharsetCanonicalName(const char * s)
+{
+  UDM_CHARSET *c= UdmGetCharSet(s);
   if(!c)return NULL;
   return c->name;
 }
 
-UDM_CHARSET * __UDMCALL UdmGetCharSet(const char * name){
+UDM_CHARSET * __UDMCALL UdmGetCharSet(const char * name)
+{
   int l,m,r,s;
 
-  l=0;
-  s=r=sizeof(alias)/sizeof(UDM_CHARSET_ALIAS)-1;
-
-  while(l<r){
-    m=(l+r)/2;
-    if(strcasecmp(alias[m].name,name)<0)l=m+1;
-    else  r=m;
+  l= 0;
+  s= r= sizeof(alias)/sizeof(UDM_CHARSET_ALIAS)-1;
+  
+  while(l < r)
+  {
+    m= (l+r)/2;
+    if(strcasecmp(alias[m].name,name)<0)
+      l=m+1;
+    else
+      r=m;
   }
   if(s==r)
     return(NULL);
-  else{
+  else
+  {
     if(!strcasecmp(alias[r].name,name))
-       return UdmGetCharSetByID(alias[r].id);
-      /*return(&built_charsets[alias[r].id]);*/
+      return UdmGetCharSetByID(alias[r].id);
     else  
-      return(NULL);
+      return NULL;
   }
   return NULL;
 }
