@@ -88,6 +88,7 @@ UDM_DSTR *UdmDSTRInit (UDM_DSTR *dstr, size_t size_page) {
 		if (dstr->free) UdmFree(dstr);
 		return(NULL);
 	}
+        dstr->data[0] = 0;
 	dstr->size_page = size_page;
 	dstr->size_data = 0;
 	dstr->size_total = size_page;
@@ -99,6 +100,20 @@ void UdmDSTRFree (UDM_DSTR *dstr) {
 	if (dstr->free) UdmFree(dstr);
 }
 
+int UdmDSTRRealloc (UDM_DSTR *dstr, size_t size_data)
+{
+  char *tmp;
+  size_t asize;
+ 
+  if (size_data <= dstr->size_total) return(UDM_OK);
+  asize= (size_data / dstr->size_page + 1) * dstr->size_page;
+  tmp= UdmRealloc(dstr->data, asize);
+  if (! tmp) return(UDM_ERROR);
+  dstr->size_total= asize;
+  dstr->data= tmp;
+  return(UDM_OK);
+}
+
 size_t UdmDSTRAppend (UDM_DSTR *dstr, const char *data, size_t size_data) {
 	size_t bytes_left = dstr->size_total - dstr->size_data;
 	size_t asize;
@@ -153,6 +168,10 @@ int UdmDSTRAppendf (UDM_DSTR *dstr, const char *fmt, ...) {
 	return(nc);
 }
 
+void UdmDSTRReset (UDM_DSTR *dstr) {
+	dstr->size_data = 0;
+}
+
 /*** str functions implementation which may be missing on some OS ***/
 
 #ifndef HAVE_BZERO
@@ -334,23 +353,39 @@ char * udm_rfc1522_decode(char * dst, const char *src){
 /************* Base 64 *********************************************/
 /* BASE64 encoding converts  3x8 bits into 4x6 bits                */
 
-__C_LINK size_t __UDMCALL udm_base64_encode (const char *src, char *store, size_t length){
-	size_t i;
-	unsigned char *p = (unsigned char *)store;
-	unsigned const char *s = (unsigned const char *)src;
+__C_LINK size_t __UDMCALL udm_base64_encode (const char *src, char *store,
+                                             size_t length)
+{
+  unsigned char *p= (unsigned char *)store;
+  unsigned const char *s= (unsigned const char *)src;
 
-	for (i = 0; i < length; i += 3){
-		*p++ = base64[s[0] >> 2];
-		*p++ = base64[((s[0] & 3) << 4) + (s[1] >> 4)];
-		*p++ = base64[((s[1] & 0xf) << 2) + (s[2] >> 6)];
-		*p++ = base64[s[2] & 0x3f];
-		s += 3;
-	}
-	/*Pad the result*/
-	if (i == length + 1) *(p - 1) = '=';
-	else if (i == length + 2) *(p - 1) = *(p - 2) = '=';
-	*p = '\0';
-	return p- (unsigned char*)store;
+  for ( ; length > 2 ; length-= 3, s+= 3)
+  {
+    *p++ = base64[s[0] >> 2];
+    *p++ = base64[((s[0] & 3) << 4) + (s[1] >> 4)];
+    *p++ = base64[((s[1] & 0xf) << 2) + (s[2] >> 6)];
+    *p++ = base64[s[2] & 0x3f];
+  }
+
+  if (length > 0)
+  {
+    *p++= base64[s[0] >> 2];
+    if (length > 1)
+    {
+      *p++ = base64[((s[0] & 3) << 4) + (s[1] >> 4)];
+      *p++ = base64[(s[1] & 0xf) << 2];
+      *p++ = '=';
+    }
+    else
+    {
+      *p++ = base64[(s[0] & 0x03) << 4];
+      *p++ = '=';
+      *p++ = '=';
+    }
+  }
+
+  *p= '\0';
+  return p - (unsigned char*)store;
 }
 
 
@@ -382,10 +417,17 @@ unsigned long UdmStartTimer(void){
 #ifdef WIN32
 	return clock();
 #else
+  struct timeval tv;
+  struct timezone tz;
+  gettimeofday(&tv, &tz);
+  return((tv.tv_sec % 100000) * 1000 + (tv.tv_usec / 1000));
+
+/*
 #undef CLOCKS_PER_SEC
 #define CLOCKS_PER_SEC (sysconf(_SC_CLK_TCK))
 	struct tms tms_tmp;
 	return (float)times(&tms_tmp)*1000/CLOCKS_PER_SEC;
+*/
 #endif
 }
 
@@ -510,28 +552,42 @@ char * UdmGetStrToken(char * s,char ** last){
 }
 
 
+static int ch2x(int ch)
+{
+  if (ch >= '0' && ch <= '9')
+    return ch - '0';
+  
+  if (ch >= 'a' && ch <= 'f')
+    return 10 + ch - 'a';
+  
+  if (ch >= 'A' && ch <= 'F')
+    return 10 + ch - 'A';
+  
+  return -1;
+}
 
-char * UdmUnescapeCGIQuery(char *d,char *s){
-int hi,lo=0;
-char *dd;
-	if((d==NULL)||(s==NULL))return(0);
-	dd=d;
-	while(*s){
-		if(*s=='%'){
-			if(strchr("0123456789",*(++s))) hi=*s-'0';
-			else hi=*s-'A'+10;
-			if(strchr("0123456789",*(++s))) lo=*s-'0';
-			else lo=*s-'A'+10;
-			*d=hi*16+lo;
-		}else
-		if(*s=='+'){
-			*d=' ';
-		}else{
-			*d=*s;
-		}
-		s++; d++;
-	}
-	*d=0;return(dd);
+char * UdmUnescapeCGIQuery(char *d,char *s)
+{
+  char *dd;
+  
+  for (dd= d; *s; s++)
+  {
+    if(*s == '%' && ch2x(s[1]) >= 0 && ch2x(s[2]) >= 0)
+    {	
+      *d++= ch2x(s[1]) * 16 + ch2x(s[2]);
+      s+= 2;
+    }
+    else if(*s=='+')
+    {
+      *d++=' ';
+    }
+    else
+    {
+      *d++=*s;
+    }
+  }
+  *d=0;
+  return(dd);
 }
 
 char * __UDMCALL UdmEscapeURL(char *d,const char *s){
@@ -2115,4 +2171,42 @@ void UdmViolationExit(void *v) {
 
 #endif /* USE_PARANOIA */
 
+const char udm_soundex[]= "01230120022455012623010202";
 
+static char udm_soundex_code(UDM_CHARSET *cset,char **ptr)
+{
+  unsigned char ch;
+  ch= toupper(**ptr);
+  if (ch < 'A' || ch > 'Z')
+  {
+    if (isalpha(ch))
+      return '0';
+    return 0;
+  }
+  return(udm_soundex[ch - 'A']);
+}
+
+
+void UdmSoundex(UDM_CHARSET *cs, char *dst, const char *src, size_t srclen)
+{
+  char ch, prev, *end;
+  const char *srcend= src + srclen;
+
+  *dst++= toupper((unsigned char)*src);
+  prev= udm_soundex_code(cs,&src);
+  end= dst + 3;
+
+  src++;
+  while (dst < end && (ch= udm_soundex_code(cs,&src)) != 0 && src < srcend)
+  {
+    src++;
+    if ((ch != '0') && (ch != prev)) /* if not skipped or double */
+    {
+      *dst++ = ch;
+    }
+    prev = ch;
+  }
+  while (dst < end)
+    *dst++ = '0';
+  *dst=0;
+}
