@@ -42,65 +42,67 @@ static int varcmp(void *v1, void *v2) {
 void UdmVarFree(UDM_VAR *S){
 	UDM_FREE(S->name);
 	UDM_FREE(S->val);
-	UDM_FREE(S->txt_val);
 	return;
 }
 
-static int UdmVarCopy(UDM_VAR *D, UDM_VAR *S){
-	D->section=S->section;
-	D->maxlen=S->maxlen;
-	D->curlen=S->curlen;
-	D->name = (char*)UdmStrdup(S->name);
-	if (S->maxlen == 0) {
-	  D->val = S->val ? (char*)UdmStrdup(S->val) : NULL;
-	  D->txt_val = S->txt_val ? (char*)UdmStrdup(S->txt_val) : NULL;
-	} else {
-	  if (S->val == NULL) {
-	    D->val = NULL;
-	  } else {
-	    D->val = (char*)UdmMalloc(S->maxlen + 4);
-	    strncpy(D->val, S->val, S->curlen + 1);
-	  }
-	  if (S->txt_val == NULL) {
-	    D->txt_val = NULL;
-	  } else {
-	    D->txt_val = (char*)UdmMalloc(S->maxlen + 4);
-	    strncpy(D->txt_val, S->txt_val, S->curlen + 1);
-	  }
-	}
-	return UDM_OK;
+static int UdmVarCopy(UDM_VAR *D, UDM_VAR *S)
+{
+  D->section= S->section;
+  D->maxlen= S->maxlen;
+  D->curlen= S->curlen;
+  D->name= (char*)UdmStrdup(S->name);
+  D->flags= S->flags;
+  if (S->maxlen == 0)
+  {
+    D->val= S->val ? (char*)UdmStrdup(S->val) : NULL;
+  } 
+  else
+  {
+    if (S->val == NULL)
+    {
+      D->val = NULL;
+    }
+    else
+    {
+      D->val = (char*)UdmMalloc(S->maxlen + 4);
+      strncpy(D->val, S->val, S->curlen + 1);
+    }
+  }
+  return UDM_OK;
 }
 
 static int UdmVarCopyNamed(UDM_VAR *D, UDM_VAR *S, const char *name){
-	D->section=S->section;
-	D->maxlen=S->maxlen;
-	D->curlen=S->curlen;
-	if(name){
-		size_t len = strlen(name) + strlen(S->name) + 3;
-		D->name = (char*)UdmMalloc(len);
-		udm_snprintf(D->name, len, "%s.%s", name, S->name);
-	}else{
-		D->name = (char*)UdmStrdup(S->name);
-	}
-	if (S->maxlen == 0) {
-	  D->val = S->val ? (char*)UdmStrdup(S->val) : NULL;
-	  D->txt_val = S->txt_val ? (char*)UdmStrdup(S->txt_val) : NULL;
-	} else {
-
-	  if (S->val == NULL) {
-	    D->val = NULL;
-	  } else {
-	    D->val = (char*)UdmMalloc(S->maxlen + 4);
-	    strncpy(D->val, S->val, S->curlen + 1);
-	  }
-	  if (S->txt_val == NULL) {
-	    D->txt_val = NULL;
-	  } else {
-	    D->txt_val = (char*)UdmMalloc(S->maxlen + 4);
-	    strncpy(D->txt_val, S->txt_val, S->curlen + 1);
-	  }
-	}
-	return UDM_OK;
+  D->section= S->section;
+  D->maxlen= S->maxlen;
+  D->curlen= S->curlen;
+  D->flags= S->flags;
+  if(name)
+  {
+    size_t len = strlen(name) + strlen(S->name) + 3;
+    D->name = (char*)UdmMalloc(len);
+    udm_snprintf(D->name, len, "%s.%s", name, S->name);
+  }
+  else
+  {
+    D->name = (char*)UdmStrdup(S->name);
+  }
+  
+  if (S->maxlen == 0)
+  {
+    D->val= S->val ? (char*)UdmStrdup(S->val) : NULL;
+  }
+  else
+  {
+    if (S->val == NULL) {
+      D->val = NULL;
+    }
+    else
+    {
+      D->val = (char*)UdmMalloc(S->maxlen + 4);
+      strncpy(D->val, S->val, S->curlen + 1);
+    }
+  }
+  return UDM_OK;
 }
 
 int UdmVarListAdd(UDM_VARLIST * Lst,UDM_VAR * S){
@@ -125,7 +127,7 @@ UDM_VAR * UdmVarListFind(UDM_VARLIST * vars,const char * name){
 	UDM_VAR key;
 	
 	if (!vars->nvars) return NULL;
-	key.name = name;
+	key.name= (char*)name;
 	return (UDM_VAR*)bsearch(&key, vars->Var, vars->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
 }
 
@@ -180,7 +182,7 @@ static int UdmVarListInsNamed(UDM_VARLIST *Lst,UDM_VAR *S, const char *name) {
 	return rc;
 }
 
-
+/*
 const char *UdmVarListFindStrTxt(UDM_VARLIST * vars,const char * name,const char * defval){
 	UDM_VAR * var;
 	if((var=UdmVarListFind(vars,name)) != NULL)
@@ -188,6 +190,7 @@ const char *UdmVarListFindStrTxt(UDM_VARLIST * vars,const char * name,const char
 	else
 		return(defval);
 }
+*/
 
 __C_LINK const char * __UDMCALL UdmVarListFindStr(UDM_VARLIST * vars, const char * name, const char * defval){
 	UDM_VAR * var;
@@ -214,7 +217,6 @@ void UdmVarListFree(UDM_VARLIST * vars){
 	for(i=0;i<vars->nvars;i++){
 		UDM_FREE(vars->Var[i].name);
 		UDM_FREE(vars->Var[i].val);
-		UDM_FREE(vars->Var[i].txt_val);
 	}
 	UDM_FREE(vars->Var);
 	vars->nvars = 0;
@@ -224,12 +226,12 @@ void UdmVarListFree(UDM_VARLIST * vars){
 
 int UdmVarListAddStr(UDM_VARLIST * vars,const char * name, const char * val){
 	vars->Var=(UDM_VAR *)UdmRealloc(vars->Var,(vars->nvars+1)*sizeof(UDM_VAR));
+	vars->Var[vars->nvars].flags= 0;
 	vars->Var[vars->nvars].section=0;
 	vars->Var[vars->nvars].maxlen=0;
 	vars->Var[vars->nvars].curlen = (val != NULL) ? strlen(val) : 0;	
 	vars->Var[vars->nvars].name = name ? (char*)UdmStrdup(name) : NULL;
 	vars->Var[vars->nvars].val = val ? (char*)UdmStrdup(val) : NULL;
-	vars->Var[vars->nvars].txt_val = val ? (char*)UdmStrdup(val) : NULL;
 	vars->nvars++;
 	UdmSort(vars->Var, vars->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
 	return vars->nvars;
@@ -263,33 +265,34 @@ int UdmVarListInsInt(UDM_VARLIST * vars,const char * name,int val){
 
 
 __C_LINK int __UDMCALL UdmVarListReplaceStr(UDM_VARLIST * vars,const char * name,const char * val){
-	UDM_VAR * var;
+  UDM_VAR * var;
 	
-	if((var=UdmVarListFind(vars,name)) != NULL) {
-		UDM_FREE(var->val);
-		UDM_FREE(var->txt_val);
-		if (var->maxlen == 0) {
-		  var->val=(val != NULL) ? (char*)UdmStrdup(val) : NULL;
-		  var->txt_val = (val != NULL) ? (char*)UdmStrdup(val) : NULL;
-		} else {
-		  if (val == NULL) {
-		    var->val = NULL;
-		  } else {
-		    var->val = (char*)UdmMalloc(var->maxlen + 4);
-		    strncpy(var->val, val, var->maxlen + 1);
-		  }
-		  if (val == NULL) {
-		    var->txt_val = NULL;
-		  } else {
-		    var->txt_val = (char*)UdmMalloc(var->maxlen + 4);
-		    strncpy(var->txt_val, val, var->maxlen + 1);
-		  }
-		}
-		var->curlen = (val != NULL) ? strlen(val) : 0;
-	}else{
-		UdmVarListAddStr(vars,name,val);
-	}
-	return vars->nvars;
+  if((var=UdmVarListFind(vars,name)) != NULL)
+  {
+    UDM_FREE(var->val);
+    if (var->maxlen == 0)
+    {
+      var->val= (val != NULL) ? (char*)UdmStrdup(val) : NULL;
+    }
+    else
+    {
+      if (val == NULL)
+      {
+        var->val = NULL;
+      }
+      else
+      {
+        var->val= (char*)UdmMalloc(var->maxlen + 4);
+        strncpy(var->val, val, var->maxlen + 1);
+      }
+    }
+    var->curlen= (val != NULL) ? strlen(val) : 0;
+  }
+  else
+  {
+    UdmVarListAddStr(vars,name,val);
+  }
+  return vars->nvars;
 }
 
 __C_LINK int __UDMCALL UdmVarListReplaceInt(UDM_VARLIST * vars,const char * name,int val){
